@@ -7,9 +7,10 @@
 
 """|UDM| allocators to allocate and lock resources for |LDAP| object creation."""
 
-from collections.abc import Sequence  # noqa: F401
+from __future__ import annotations
+
 from logging import getLogger
-from typing import overload
+from typing import TYPE_CHECKING, overload
 
 import ldap
 from ldap.filter import filter_format
@@ -20,6 +21,10 @@ import univention.admin.uexceptions
 from univention.admin._ucr import configRegistry
 
 
+if TYPE_CHECKING:
+    from collections.abc import Sequence
+
+
 try:
     from typing import Literal
     _TypesUidGid = Literal["uidNumber", "gidNumber"]
@@ -33,7 +38,7 @@ log = getLogger('ADMIN')
 translation = univention.admin.localization.translation('univention/admin')
 _ = translation.translate
 
-_type2attr = {
+_type2attr: dict[_Types, str] = {
     'uidNumber': 'uidNumber',
     'gidNumber': 'gidNumber',
     'uid': 'uid',
@@ -47,8 +52,8 @@ _type2attr = {
     'groupName': 'cn',
     'cn-uid-position': 'cn',  # ['cn', 'uid', 'ou'],
     'univentionObjectIdentifier': 'univentionObjectIdentifier',
-}  # type: dict[_Types, str]
-_type2scope = {
+}
+_type2scope: dict[_Types, _Scopes] = {
     'uidNumber': 'base',
     'gidNumber': 'base',
     'uid': 'domain',
@@ -62,19 +67,19 @@ _type2scope = {
     'groupName': 'domain',
     'cn-uid-position': 'one',
     'univentionObjectIdentifier': 'domain',
-}  # type: dict[_Types, _Scopes]
+}
 
 
 def requestUserSid(
-    lo,  # type: univention.admin.uldap.access
-    position,  # type: univention.admin.uldap.position
-    uid_s,  # type: str
-):  # type: (...) -> str
+    lo: univention.admin.uldap.access,
+    position: univention.admin.uldap.position,
+    uid_s: str,
+) -> str:
     uid = int(uid_s)
     algorithmical_rid_base = 1000
     rid = str(uid * 2 + algorithmical_rid_base)
 
-    searchResult = lo.search(filter='objectClass=sambaDomain', attr=['sambaSID'])
+    searchResult = lo.authz_connection.search(filter='objectClass=sambaDomain', attr=['sambaSID'])
     domainsid = searchResult[0][1]['sambaSID'][0].decode('ASCII')
     sid = domainsid + '-' + rid
 
@@ -84,11 +89,11 @@ def requestUserSid(
 
 
 def requestGroupSid(
-    lo,  # type: univention.admin.uldap.access
-    position,  # type: univention.admin.uldap.position
-    gid_s,  # type: str
-    generateDomainLocalSid=False,  # type: bool
-):  # type: (...) -> str
+    lo: univention.admin.uldap.access,
+    position: univention.admin.uldap.position,
+    gid_s: str,
+    generateDomainLocalSid: bool = False,
+) -> str:
     gid = int(gid_s)
     algorithmical_rid_base = 1000
     rid = str(gid * 2 + algorithmical_rid_base + 1)
@@ -96,7 +101,7 @@ def requestGroupSid(
     if generateDomainLocalSid:
         sid = 'S-1-5-32-' + rid
     else:
-        searchResult = lo.search(filter='objectClass=sambaDomain', attr=['sambaSID'])
+        searchResult = lo.authz_connection.search(filter='objectClass=sambaDomain', attr=['sambaSID'])
         domainsid = searchResult[0][1]['sambaSID'][0].decode('ASCII')
         sid = domainsid + '-' + rid
 
@@ -104,15 +109,15 @@ def requestGroupSid(
 
 
 def acquireRange(
-    lo,  # type: univention.admin.uldap.access
-    position,  # type: univention.admin.uldap.position
-    atype,  # type: _Types
-    attr,  # type: str
-    ranges,  # type: Sequence[dict[str, int]]
-    scope='base',  # type: _Scopes
-):  # type: (...) -> str
+    lo: univention.admin.uldap.access,
+    position: univention.admin.uldap.position,
+    atype: _Types,
+    attr: str,
+    ranges: Sequence[dict[str, int]],
+    scope: _Scopes = 'base',
+) -> str:
     log.debug('ALLOCATE: Start allocation for type = %r', atype)
-    start_id = lo.getAttr('cn=%s,cn=temporary,cn=univention,%s' % (ldap.dn.escape_dn_chars(atype), position.getBase()), 'univentionLastUsedValue')
+    start_id = lo.authz_connection.getAttr('cn=%s,cn=temporary,cn=univention,%s' % (ldap.dn.escape_dn_chars(atype), position.getBase()), 'univentionLastUsedValue')
 
     log.debug('ALLOCATE: Start ID = %r', start_id)
 
@@ -155,7 +160,7 @@ def acquireRange(
             else:
                 _filter = '(%s=%d)' % (attr, startID)
             log.debug('ALLOCATE: searchfor %r', _filter)
-            if lo.searchDn(base=position.getBase(), filter=_filter):
+            if lo.authz_connection.searchDn(base=position.getBase(), filter=_filter):
                 log.debug('ALLOCATE: Already used ID %r', startID)
                 univention.admin.locking.unlock(lo, position, atype, str(startID).encode('utf-8'), scope=scope)
                 if other:
@@ -172,28 +177,28 @@ def acquireRange(
 
 
 def acquireUnique(
-    lo,  # type: univention.admin.uldap.access
-    position,  # type: univention.admin.uldap.position
-    type,  # type: _Types
-    value,  # type: str
-    attr,  # type: str
-    scope='base',  # type: _Scopes
-):  # type: (...) -> str
+    lo: univention.admin.uldap.access,
+    position: univention.admin.uldap.position,
+    type: _Types,
+    value: str,
+    attr: str,
+    scope: _Scopes = 'base',
+) -> str:
     log.debug('LOCK acquireUnique scope = %s', scope)
     searchBase = position.getDomain() if scope == "domain" else position.getBase()
 
     if type == "aRecord":  # uniqueness is only relevant among hosts (one or more dns entries having the same aRecord as a host are allowed)
         univention.admin.locking.lock(lo, position, type, value.encode('utf-8'), scope=scope)
-        if not lo.searchDn(base=searchBase, filter=filter_format('(&(objectClass=univentionHost)(%s=%s))', (attr, value))):
+        if not lo.authz_connection.searchDn(base=searchBase, filter=filter_format('(&(objectClass=univentionHost)(%s=%s))', (attr, value))):
             return value
     elif type in ['groupName', 'uid'] and configRegistry.is_true('directory/manager/user_group/uniqueness', True):
         univention.admin.locking.lock(lo, position, type, value.encode('utf-8'), scope=scope)
-        if not lo.searchDn(base=searchBase, filter=filter_format('(|(&(cn=%s)(|(objectClass=univentionGroup)(objectClass=sambaGroupMapping)(objectClass=posixGroup)))(uid=%s))', (value, value))):
+        if not lo.authz_connection.searchDn(base=searchBase, filter=filter_format('(|(&(cn=%s)(|(objectClass=univentionGroup)(objectClass=sambaGroupMapping)(objectClass=posixGroup)))(uid=%s))', (value, value))):
             log.debug('ALLOCATE return %s', value)
             return value
     elif type == "groupName":  # search filter is more complex then in general case
         univention.admin.locking.lock(lo, position, type, value.encode('utf-8'), scope=scope)
-        if not lo.searchDn(base=searchBase, filter=filter_format('(&(%s=%s)(|(objectClass=univentionGroup)(objectClass=sambaGroupMapping)(objectClass=posixGroup)))', (attr, value))):
+        if not lo.authz_connection.searchDn(base=searchBase, filter=filter_format('(&(%s=%s)(|(objectClass=univentionGroup)(objectClass=sambaGroupMapping)(objectClass=posixGroup)))', (attr, value))):
             log.debug('ALLOCATE return %s', value)
             return value
     elif type == 'cn-uid-position':
@@ -205,14 +210,14 @@ def acquireUnique(
             return value
 
         assert base is not None
-        if all(ldap.dn.str2dn(x)[0][0][0] not in attrs for x in lo.searchDn(base=base, filter='(|%s)' % ''.join(filter_format('(%s=%s)', (attr, value)) for attr in attrs), scope=scope)):
+        if all(ldap.dn.str2dn(x)[0][0][0] not in attrs for x in lo.authz_connection.searchDn(base=base, filter='(|%s)' % ''.join(filter_format('(%s=%s)', (attr, value)) for attr in attrs), scope=scope)):
             return value
         raise univention.admin.uexceptions.alreadyUsedInSubtree('name=%r position=%r' % (value, base))
     elif type in ('mailPrimaryAddress', 'mailAlternativeAddress') and configRegistry.is_true('directory/manager/mail-address/uniqueness'):
         log.debug('LOCK univention.admin.locking.lock scope = %s', scope)
         univention.admin.locking.lock(lo, position, 'mailPrimaryAddress', value.encode('utf-8'), scope=scope)
         other = 'mailPrimaryAddress' if type == 'mailAlternativeAddress' else 'mailAlternativeAddress'
-        if not lo.searchDn(base=searchBase, filter=filter_format('(|(%s=%s)(%s=%s))', (attr, value, other, value))):
+        if not lo.authz_connection.searchDn(base=searchBase, filter=filter_format('(|(%s=%s)(%s=%s))', (attr, value, other, value))):
             log.debug('ALLOCATE return %s', value)
             return value
     elif type == 'mailAlternativeAddress':
@@ -220,7 +225,7 @@ def acquireUnique(
     else:
         log.debug('LOCK univention.admin.locking.lock scope = %s', scope)
         univention.admin.locking.lock(lo, position, type, value.encode('utf-8'), scope=scope)
-        if not lo.searchDn(base=searchBase, filter=filter_format('%s=%s', (attr, value))):
+        if not lo.authz_connection.searchDn(base=searchBase, filter=filter_format('%s=%s', (attr, value))):
             log.debug('ALLOCATE return %s', value)
             return value
 
@@ -229,30 +234,30 @@ def acquireUnique(
 
 @overload
 def request(
-    lo,  # type: univention.admin.uldap.access
-    position,  # type: univention.admin.uldap.position
-    type,  # type: _TypesUidGid
-    value=None,  # type: str | None
-):  # type: (...) -> str
+    lo: univention.admin.uldap.access,
+    position: univention.admin.uldap.position,
+    type: _TypesUidGid,
+    value: str | None = None,
+) -> str:
     pass
 
 
 @overload
 def request(
-    lo,  # type: univention.admin.uldap.access
-    position,  # type: univention.admin.uldap.position
-    type,  # type: _Types
-    value,  # type: str
-):  # type: (...) -> str
+    lo: univention.admin.uldap.access,
+    position: univention.admin.uldap.position,
+    type: _Types,
+    value: str,
+) -> str:
     pass
 
 
 def request(
-    lo,  # type: univention.admin.uldap.access
-    position,  # type: univention.admin.uldap.position
-    type,  # type: _Types
-    value=None,  # type: str | None
-):  # type: (...) -> str
+    lo: univention.admin.uldap.access,
+    position: univention.admin.uldap.position,
+    type: _Types,
+    value: str | None = None,
+) -> str:
     if type in ('uidNumber', 'gidNumber'):
         return acquireRange(lo, position, type, _type2attr[type], [{'first': 1000, 'last': 55000}, {'first': 65536, 'last': 1000000}], scope=_type2scope[type])
     assert value is not None
@@ -260,23 +265,23 @@ def request(
 
 
 def confirm(
-    lo,  # type: univention.admin.uldap.access
-    position,  # type: univention.admin.uldap.position
-    type,  # type: _Types
-    value,  # type: str
-    updateLastUsedValue=True,  # type: bool
-):  # type: (...) -> None
+    lo: univention.admin.uldap.access,
+    position: univention.admin.uldap.position,
+    type: _Types,
+    value: str,
+    updateLastUsedValue: bool = True,
+) -> None:
     if type in ('uidNumber', 'gidNumber') and updateLastUsedValue:
-        lo.modify('cn=%s,cn=temporary,cn=univention,%s' % (ldap.dn.escape_dn_chars(type), position.getBase()), [('univentionLastUsedValue', b'1', value.encode('utf-8'))])
+        lo.authz_connection.modify('cn=%s,cn=temporary,cn=univention,%s' % (ldap.dn.escape_dn_chars(type), position.getBase()), [('univentionLastUsedValue', b'1', value.encode('utf-8'))])
     elif type == 'cn-uid-position':
         return
     univention.admin.locking.unlock(lo, position, type, value.encode('utf-8'), _type2scope[type])
 
 
 def release(
-    lo,  # type: univention.admin.uldap.access
-    position,  # type: univention.admin.uldap.position
-    type,  # type: _Types
-    value,  # type: str
-):  # type: (...) -> None
+    lo: univention.admin.uldap.access,
+    position: univention.admin.uldap.position,
+    type: _Types,
+    value: str,
+) -> None:
     univention.admin.locking.unlock(lo, position, type, value.encode('utf-8'), _type2scope[type])
