@@ -10,7 +10,6 @@ from __future__ import annotations
 
 import hashlib
 import re
-from collections.abc import Iterable  # noqa: F401
 from datetime import datetime
 from typing import TYPE_CHECKING
 
@@ -24,8 +23,8 @@ from univention.admin._ucr import configRegistry
 
 
 if TYPE_CHECKING:
-    import univention.admin.handlers
-    import univention.admin.handlers.blocklists.list  # noqa: TC004
+    from collections.abc import Iterable
+    from typing import Any
 
 
 translation = univention.admin.localization.translation('univention.admin.handlers')
@@ -34,18 +33,11 @@ _ = translation.translate
 BLOCKLIST_BASE = 'cn=blocklists,cn=internal'
 
 
-try:
-    unicode  # noqa: B018
-except NameError:
-    unicode = str
-
-
-def hash_blocklist_value(value):  # type: (bytes) -> str
+def hash_blocklist_value(value: bytes) -> str:
     return 'sha256:%s' % hashlib.sha256(value.lower()).hexdigest()
 
 
-def parse_timedelta(timedelta_string):
-    # type: (str) -> relativedelta | None
+def parse_timedelta(timedelta_string: str) -> relativedelta | None:
     """
     Parse time delta.
 
@@ -59,11 +51,10 @@ def parse_timedelta(timedelta_string):
 
 
 @univention.admin._ldap_cache(ttl=120)
-def get_blocklist_config(lo):
-    # type: (univention.admin.uldap.access) -> dict
+def get_blocklist_config(lo: univention.admin.uldap.access) -> dict:
     config = {}
     try:
-        for blist in univention.admin.handlers.blocklists.list.lookup(None, lo, 'entryUUID=*', base=BLOCKLIST_BASE, scope='one'):
+        for blist in univention.admin.modules.get('blocklists/list').lookup(None, lo, 'entryUUID=*', base=BLOCKLIST_BASE, scope='one', authz=False):
             config[blist.dn] = blist.get('retentionTime', '30d')
             for mod, prop in blist.get('blockingProperties', []):
                 config.setdefault(mod, {})[prop] = blist.dn
@@ -74,14 +65,12 @@ def get_blocklist_config(lo):
     return config
 
 
-def get_blocking_udm_properties(udm_obj):
-    # type: (univention.admin.handlers.simpleLdap) -> dict
+def get_blocking_udm_properties(udm_obj: univention.admin.handlers.simpleLdap) -> dict:
     config = get_blocklist_config(udm_obj.lo_machine_primary)
     return config.get(udm_obj.module, {})
 
 
-def get_blockeduntil(dn, lo):
-    # type: (str, univention.admin.uldap.access) -> str
+def get_blockeduntil(dn: str, lo: univention.admin.uldap.access) -> str:
     config = get_blocklist_config(lo)
     retention = config.get(dn, '30d')
     blocking_duration = parse_timedelta(retention)
@@ -89,22 +78,19 @@ def get_blockeduntil(dn, lo):
     return datetime.strftime(blocked_until, '%Y%m%d%H%M%SZ')
 
 
-def blocklist_enabled(udm_obj):
-    # type: (univention.admin.handlers.simpleLdap) -> bool
+def blocklist_enabled(udm_obj: univention.admin.handlers.simpleLdap) -> bool:
     return not udm_obj.module.startswith('blocklists/') and configRegistry.is_true('directory/manager/blocklist/enabled', False)
 
 
-def get_blocklist_values_from_udm_property(udm_property_value, udm_property_name):
-    # type: (Any, str) -> list[Any]
-    if isinstance(udm_property_value, str | unicode):
+def get_blocklist_values_from_udm_property(udm_property_value: Any, udm_property_name: str) -> list[Any]:
+    if isinstance(udm_property_value, str):
         return [udm_property_value]
-    if not isinstance(udm_property_value, list) or not all(isinstance(mem, str | unicode) for mem in udm_property_value):
+    if not isinstance(udm_property_value, list) or not all(isinstance(mem, str) for mem in udm_property_value):
         raise RuntimeError('The property %r uses a complex syntax. This is not supported for blocklist objects.' % udm_property_name)
     return udm_property_value
 
 
-def create_blocklistentry(udm_obj):
-    # type: (univention.admin.handlers.simpleLdap) -> list
+def create_blocklistentry(udm_obj: univention.admin.handlers.simpleLdap) -> list:
     if not blocklist_enabled(udm_obj):
         return []
     blocklist_entries = []
@@ -112,7 +98,7 @@ def create_blocklistentry(udm_obj):
         if (not udm_obj.exists() and udm_obj.oldinfo.get(prop)) or (udm_obj.hasChanged(prop) and udm_obj.oldinfo.get(prop)):
             blocklist_position = univention.admin.uldap.position(bl_dn)
             for value in get_blocklist_values_from_udm_property(udm_obj.oldinfo[prop], prop):
-                blocklistentry = univention.admin.handlers.blocklists.entry.object(None, udm_obj.lo_machine_primary, blocklist_position)
+                blocklistentry = univention.admin.modules.get('blocklists/entry').object(None, udm_obj.lo_machine_primary, blocklist_position)
                 blocklistentry.open()
                 blocklistentry['value'] = value
                 blocklistentry['originUniventionObjectIdentifier'] = udm_obj.entry_uuid
@@ -126,8 +112,7 @@ def create_blocklistentry(udm_obj):
     return blocklist_entries
 
 
-def check_blocklistentry(udm_obj):
-    # type: (univention.admin.handlers.simpleLdap) -> None
+def check_blocklistentry(udm_obj: univention.admin.handlers.simpleLdap) -> None:
     if not blocklist_enabled(udm_obj):
         return
     for prop, bl_dn in get_blocking_udm_properties(udm_obj).items():
@@ -140,8 +125,7 @@ def check_blocklistentry(udm_obj):
                     raise univention.admin.uexceptions.valueError(_('The value "%(value)s" is blocked for the property "%(prop)s".') % {'value': value, 'prop': prop}, property=prop)
 
 
-def cleanup_blocklistentry(blocklist_entries, udm_obj):
-    # type: (Iterable, univention.admin.handlers.simpleLdap) -> None
+def cleanup_blocklistentry(blocklist_entries: Iterable, udm_obj: univention.admin.handlers.simpleLdap) -> None:
     for entry in blocklist_entries:
         try:
             udm_obj.lo_machine_primary.delete(entry)
