@@ -7,7 +7,7 @@
 
 """|UDM| module for all computer objects"""
 
-from typing import TYPE_CHECKING  # noqa: F401
+from __future__ import annotations
 
 import univention.admin
 import univention.admin.handlers
@@ -30,7 +30,7 @@ object_name_plural = _('Computers')
 long_description = ''
 operations = ['search']
 virtual = True
-options = {}  # type: dict[str, univention.admin.option]
+options: dict[str, univention.admin.option] = {}
 property_descriptions = {
     'name': univention.admin.property(
         short_description=_('Name'),
@@ -93,8 +93,7 @@ mapping.register('mac', 'macAddress', encoding='ASCII')
 class object(univention.admin.handlers.simpleLdap):
     module = module
 
-    def open(self):
-        # type: () -> None
+    def open(self) -> None:
         super().open()
         if 'name' in self.info and 'domain' in self.info:
             # in syntax.py IComputer_FQDN key and label are '%(name)s.%(domain)s' for
@@ -104,14 +103,12 @@ class object(univention.admin.handlers.simpleLdap):
             self.save()
 
 
-def lookup(co, lo, filter_s, base='', superordinate=None, scope='sub', unique=False, required=False, timeout=-1, sizelimit=0):
-    # type: (None, univention.admin.uldap.access, str, str, univention.admin.handlers.simpleLdap | None, str, bool, bool, int, int) -> list[univention.admin.handlers.simpleLdap]
-    res = []  # type: list[univention.admin.handlers.simpleLdap]
+def lookup(co: None, lo: univention.admin.uldap.access, filter_s: str, base: str = '', superordinate: univention.admin.handlers.simpleLdap | None = None, scope: str = 'sub', unique: bool = False, required: bool = False, timeout: int = -1, sizelimit: int = 0) -> list[univention.admin.handlers.simpleLdap]:
+    res: list[univention.admin.handlers.simpleLdap] = []
     for computer in univention.admin.handlers.computers.computers:
         res += computer.lookup(co, lo, filter_s, base, superordinate, scope, unique, required, timeout, sizelimit)
     return res
 
 
-def identify(dn, attr, canonical=False):
-    # type: (str, univention.admin.handlers._Attributes, bool) -> None
+def identify(dn: str, attr: univention.admin.handlers._Attributes, canonical: bool = False) -> None:
     pass
