@@ -7,6 +7,8 @@
 
 """|UDM| module for containers"""
 
+from __future__ import annotations
+
 import univention.admin.filter
 import univention.admin.handlers
 import univention.admin.localization
@@ -233,8 +235,7 @@ class object(univention.admin.handlers.simpleLdap):
         'licensePath': 'univentionLicenseObject',
     }
 
-    def open(self):
-        # type: () -> None
+    def open(self) -> None:
         univention.admin.handlers.simpleLdap.open(self)
 
         pathResult, self.default_dn = default_container_for_objects(self.lo, self.position.getDomain())
@@ -249,15 +250,14 @@ class object(univention.admin.handlers.simpleLdap):
 
         self.save()
 
-    def _ldap_post_create(self):
-        # type: () -> None
+    def _ldap_post_create(self) -> None:
         super()._ldap_post_create()
         changes = []
 
         dn_bytes = self.dn.encode('UTF-8')
         for (prop, attr) in self.PATH_KEYS.items():
             if self.oldinfo.get(prop) != self.info.get(prop):
-                entries = self.lo.getAttr(self.default_dn, attr)
+                entries = self.lo.authz_connection.getAttr(self.default_dn, attr)
                 if self.info[prop] == '0':
                     if dn_bytes in entries:
                         changes.append((attr, dn_bytes, b''))
@@ -266,18 +266,16 @@ class object(univention.admin.handlers.simpleLdap):
                         changes.append((attr, b'', dn_bytes))
 
         if changes:
-            self.lo.modify(self.default_dn, changes)
+            self.lo.authz_connection.modify(self.default_dn, changes)
 
-    def _ldap_pre_rename(self, newdn):
-        # type: (str) -> None
+    def _ldap_pre_rename(self, newdn: str) -> None:
         super()._ldap_pre_rename(newdn)
         self.move(newdn)
 
-    def _ldap_post_move(self, olddn):
-        # type: (str) -> None
+    def _ldap_post_move(self, olddn: str) -> None:
         super()._ldap_post_move(olddn)
         settings_module = univention.admin.modules._get('settings/directory')
-        settings_object = univention.admin.objects.get(settings_module, None, self.lo, position='', dn=self.default_dn)
+        settings_object = univention.admin.objects.get(settings_module, None, self.lo, position='', dn=self.default_dn, authz=False)
         settings_object.open()
         needs_modify = False
         for attr in ['dns', 'license', 'computers', 'shares', 'groups', 'printers', 'policies', 'dhcp', 'networks', 'users', 'mail']:
@@ -288,8 +286,7 @@ class object(univention.admin.handlers.simpleLdap):
         if needs_modify:
             settings_object.modify()
 
-    def _ldap_post_modify(self):
-        # type: () -> None
+    def _ldap_post_modify(self) -> None:
         super()._ldap_post_modify()
         changes = []
 
@@ -301,10 +298,9 @@ class object(univention.admin.handlers.simpleLdap):
                 else:
                     changes.append((attr, b'', dn_bytes))
         if changes:
-            self.lo.modify(self.default_dn, changes)
+            self.lo.authz_connection.modify(self.default_dn, changes)
 
-    def _ldap_pre_remove(self):
-        # type: () -> None
+    def _ldap_pre_remove(self) -> None:
         super()._ldap_pre_remove()
         changes = []
 
@@ -314,11 +310,10 @@ class object(univention.admin.handlers.simpleLdap):
         for prop, attr in self.PATH_KEYS.items():
             if self.oldinfo.get(prop) == '1':
                 changes.append((attr, dn_bytes, b''))
-        self.lo.modify(self.default_dn, changes)
+        self.lo.authz_connection.modify(self.default_dn, changes)
 
     @classmethod
-    def unmapped_lookup_filter(cls):
-        # type: () -> univention.admin.filter.conjunction
+    def unmapped_lookup_filter(cls) -> univention.admin.filter.conjunction:
         return univention.admin.filter.conjunction('&', [
             univention.admin.filter.expression('objectClass', 'organizationalRole'),
             univention.admin.filter.conjunction('!', [univention.admin.filter.expression('cn', 'univention')]),
@@ -330,6 +325,5 @@ lookup = object.lookup
 lookup_filter = object.lookup_filter
 
 
-def identify(dn, attr, canonical=False):
-    # type: (str, univention.admin.handlers._Attributes, bool) -> bool
+def identify(dn: str, attr: univention.admin.handlers._Attributes, canonical: bool = False) -> bool:
     return b'organizationalRole' in attr.get('objectClass', []) and attr.get("cn", []) != [b"univention"] and b'univentionBase' not in attr.get('objectClass', [])
