@@ -7,6 +7,8 @@
 
 """|UDM| module for Organizational Unit containers"""
 
+from __future__ import annotations
+
 import univention.admin.filter
 import univention.admin.handlers
 import univention.admin.localization
@@ -235,8 +237,7 @@ class object(univention.admin.handlers.simpleLdap):
         'licensePath': 'univentionLicenseObject',
     }
 
-    def open(self):
-        # type: () -> None
+    def open(self) -> None:
         univention.admin.handlers.simpleLdap.open(self)
 
         pathResult, self.default_dn = default_container_for_objects(self.lo, self.position.getDomain())
@@ -251,25 +252,23 @@ class object(univention.admin.handlers.simpleLdap):
 
         self.save()
 
-    def _ldap_pre_create(self):
-        # type: () -> None
+    def _ldap_pre_create(self) -> None:
         super()._ldap_pre_create()
         if configRegistry.is_false('directory/manager/child/cn/ou', True) and not self.lo.compare_dn(self.position.getDn(), configRegistry.get('ldap/base')):
             # it is possible to have a basedn with cn=foo
             # in this case it is allowed to create a ou
             # under a cn.
-            if any(m and m.module == 'container/cn' for m in univention.admin.modules.identify(self.position.getDn(), self.lo.get(self.position.getDn()))):
+            if any(m and m.module == 'container/cn' for m in univention.admin.modules.identify(self.position.getDn(), self.lo.authz_connection.get(self.position.getDn()))):
                 raise univention.admin.uexceptions.invalidChild(_('It is not allowed to create a container/ou as child object of a container/cn.'))
 
-    def _ldap_post_create(self):
-        # type: () -> None
+    def _ldap_post_create(self) -> None:
         super()._ldap_post_create()
         changes = []
 
         dn_bytes = self.dn.encode('UTF-8')
         for (prop, attr) in self.PATH_KEYS.items():
             if self.oldinfo.get(prop) != self.info.get(prop):
-                entries = self.lo.getAttr(self.default_dn, attr)
+                entries = self.lo.authz_connection.getAttr(self.default_dn, attr)
                 if self.info[prop] == '0':
                     if dn_bytes in entries:
                         changes.append((attr, self.dn.encode('utf-8'), b''))
@@ -278,18 +277,16 @@ class object(univention.admin.handlers.simpleLdap):
                         changes.append((attr, b'', self.dn.encode('utf-8')))
 
         if changes:
-            self.lo.modify(self.default_dn, changes)
+            self.lo.authz_connection.modify(self.default_dn, changes)
 
-    def _ldap_pre_rename(self, newdn):
-        # type: (str) -> None
+    def _ldap_pre_rename(self, newdn: str) -> None:
         super()._ldap_pre_rename(newdn)
         self.move(newdn)
 
-    def _ldap_post_move(self, olddn):
-        # type: (str) -> None
+    def _ldap_post_move(self, olddn: str) -> None:
         super()._ldap_post_move(olddn)
         settings_module = univention.admin.modules._get('settings/directory')
-        settings_object = univention.admin.objects.get(settings_module, None, self.lo, position='', dn=self.default_dn)
+        settings_object = univention.admin.objects.get(settings_module, None, self.lo, position='', dn=self.default_dn, authz=False)
         settings_object.open()
         for attr in ['dns', 'license', 'computers', 'shares', 'groups', 'printers', 'policies', 'dhcp', 'networks', 'users', 'mail']:
             if olddn in settings_object[attr]:
@@ -297,8 +294,7 @@ class object(univention.admin.handlers.simpleLdap):
                 settings_object[attr].append(self.dn)
         settings_object.modify()
 
-    def _ldap_post_modify(self):
-        # type: () -> None
+    def _ldap_post_modify(self) -> None:
         super()._ldap_post_modify()
         changes = []
 
@@ -310,10 +306,9 @@ class object(univention.admin.handlers.simpleLdap):
                 else:
                     changes.append((attr, b'', dn_bytes))
         if changes:
-            self.lo.modify(self.default_dn, changes)
+            self.lo.authz_connection.modify(self.default_dn, changes)
 
-    def _ldap_pre_remove(self):
-        # type: () -> None
+    def _ldap_pre_remove(self) -> None:
         super()._ldap_pre_remove()
         changes = []
 
@@ -323,11 +318,10 @@ class object(univention.admin.handlers.simpleLdap):
         for prop, attr in self.PATH_KEYS.items():
             if self.oldinfo.get(prop) == '1':
                 changes.append((attr, dn_bytes, b''))
-        self.lo.modify(self.default_dn, changes)
+        self.lo.authz_connection.modify(self.default_dn, changes)
 
     @classmethod
-    def unmapped_lookup_filter(cls):
-        # type: () -> univention.admin.filter.conjunction
+    def unmapped_lookup_filter(cls) -> univention.admin.filter.conjunction:
         return univention.admin.filter.conjunction('&', [
             univention.admin.filter.expression('objectClass', 'organizationalUnit'),
             univention.admin.filter.conjunction('!', [univention.admin.filter.expression('objectClass', 'univentionBase')]),
@@ -338,6 +332,5 @@ lookup = object.lookup
 lookup_filter = object.lookup_filter
 
 
-def identify(dn, attr, canonical=False):
-    # type: (str, univention.admin.handlers._Attributes, bool) -> bool
+def identify(dn: str, attr: univention.admin.handlers._Attributes, canonical: bool = False) -> bool:
     return b'organizationalUnit' in attr.get('objectClass', []) and b'univentionBase' not in attr.get('objectClass', [])
