@@ -115,8 +115,7 @@ class object(DHCPBase):
     }
     permits_dhcp2udm = {value: key for (key, value) in permits_udm2dhcp.items()}
 
-    def open(self):
-        # type: () -> None
+    def open(self) -> None:
         univention.admin.handlers.simpleLdap.open(self)
 
         for i in [x.decode('UTF-8') for x in self.oldattr.get('dhcpPermitList', [])]:
@@ -127,8 +126,7 @@ class object(DHCPBase):
 
         self.save()
 
-    def ready(self):
-        # type: () -> None
+    def ready(self) -> None:
         super().ready()
         # Use ipaddress.IPv4Interface().network to be liberal with subnet notation
         subnet = ipaddress.IPv4Interface('%(subnet)s/%(subnetmask)s' % self.superordinate.info).network
