@@ -7,7 +7,9 @@
 
 """|UDM| module for |DNS| records"""
 
-from typing import Any  # noqa: F401
+from __future__ import annotations
+
+from typing import Any
 
 from ldap.dn import str2dn
 
@@ -22,32 +24,32 @@ ARPA_IP4 = '.in-addr.arpa'
 ARPA_IP6 = '.ip6.arpa'
 
 
-def is_dns(attr):  # type: (udm_handlers._Attributes) -> bool
+def is_dns(attr: udm_handlers._Attributes) -> bool:
     """Are the given LDAP attributes a DNS entry?"""
     return b'dNSZone' in attr.get('objectClass', [])
 
 
-def is_zone(attr):  # type: (udm_handlers._Attributes) -> bool
+def is_zone(attr: udm_handlers._Attributes) -> bool:
     """Are the given LDAP attributes a DNS zone entry?"""
     return bool(attr.get("sOARecord"))
 
 
-def is_reverse_zone(attr):  # type: (udm_handlers._Attributes) -> bool
+def is_reverse_zone(attr: udm_handlers._Attributes) -> bool:
     """Are the given LDAP attributes a DNS entry in a forward zone?"""
     return attr["zoneName"][0].decode("ASCII").endswith((ARPA_IP4, ARPA_IP6))
 
 
-def is_forward_zone(attr):  # type: (udm_handlers._Attributes) -> bool
+def is_forward_zone(attr: udm_handlers._Attributes) -> bool:
     """Are the given LDAP attributes a DNS entry in a reverse zone?"""
     return not is_reverse_zone(attr)
 
 
-def has_any(attr, *attrs):  # type: (udm_handlers._Attributes, *str) -> bool
+def has_any(attr: udm_handlers._Attributes, *attrs: str) -> bool:
     """Are any of the named LDAP attributes present?"""
     return any(attr.get(a) for a in attrs)
 
 
-def is_not_handled_by_other_module_than(attr, module):  # type: (udm_handlers._Attributes, str) -> bool
+def is_not_handled_by_other_module_than(attr: udm_handlers._Attributes, module: str) -> bool:
     """Are the given LDAP attributes handled by the specified UDM module?"""
     mod = module.encode('ASCII')
     return mod in attr.get('univentionObjectType', [mod])
@@ -57,43 +59,38 @@ class DNSBase(udm_handlers.simpleLdap):
 
     def __init__(
         self,
-        co,  # type: None
-        lo,  # type: univention.admin.uldap.access
-        position,  # type: univention.admin.uldap.position | None
-        dn='',  # type: str
-        superordinate=None,  # type: udm_handlers.simpleLdap | None
-        attributes=None,  # type: udm_handlers._Attributes | None
-        update_zone=True,  # type: bool
-    ):  # type: (...) -> None
+        co: None,
+        lo: univention.admin.uldap.access,
+        position: univention.admin.uldap.position | None,
+        dn: str = '',
+        superordinate: udm_handlers.simpleLdap | None = None,
+        attributes: udm_handlers._Attributes | None = None,
+        update_zone: bool = True,
+    ) -> None:
         self.update_zone = update_zone
         univention.admin.handlers.simpleLdap.__init__(self, co, lo, position, dn, superordinate, attributes=attributes)
 
-    def _updateZone(self):
-        # type: () -> None
+    def _updateZone(self) -> None:
         if self.update_zone:
             assert self.superordinate is not None
             self.superordinate.open()
             self.superordinate.modify()
 
-    def _ldap_post_create(self):
-        # type: () -> None
+    def _ldap_post_create(self) -> None:
         super()._ldap_post_create()
         self._updateZone()
 
-    def _ldap_post_modify(self):
-        # type: () -> None
+    def _ldap_post_modify(self) -> None:
         super()._ldap_post_modify()
         if self.hasChanged(self.descriptions.keys()):
             self._updateZone()
 
-    def _ldap_post_remove(self):
-        # type: () -> None
+    def _ldap_post_remove(self) -> None:
         super()._ldap_post_remove()
         self._updateZone()
 
     @staticmethod
-    def _zone(superordinate):
-        # type: (udm_handlers.simpleLdap) -> str
+    def _zone(superordinate: udm_handlers.simpleLdap) -> str:
         """Extract DNS zone name from DN of superordinate."""
         dn = superordinate.dn
         for rdn in str2dn(dn):
@@ -102,29 +99,25 @@ class DNSBase(udm_handlers.simpleLdap):
                     return v
         raise ValueError(dn)
 
-    def _ldap_addlist(self):
-        # type: () -> list[tuple[str, Any]]
+    def _ldap_addlist(self) -> list[tuple[str, Any]]:
         assert self.superordinate is not None
         zone = self._zone(self.superordinate)
         return [*super()._ldap_addlist(), ('zoneName', zone.encode('ASCII'))]
 
     @classmethod
-    def lookup_filter_superordinate(cls, filter, superordinate):
-        # type: (udm_filter.conjunction, udm_handlers.simpleLdap) -> udm_filter.conjunction
+    def lookup_filter_superordinate(cls, filter: udm_filter.conjunction, superordinate: udm_handlers.simpleLdap) -> udm_filter.conjunction:
         filter.expressions.append(udm_filter.expression('zoneName', cls._zone(superordinate), escape=True))
         return filter
 
 
 # UNUSED:
-def makeContactPerson(obj, arg):
-    # type: (udm_handlers.simpleLdap, object) -> str
+def makeContactPerson(obj: udm_handlers.simpleLdap, arg: object) -> str:
     """Create contact Email-address for domain."""
     domain = obj.position.getDomain()
     return 'root@%s.' % (domain.replace('dc=', '').replace(',', '.'),)
 
 
-def unescapeSOAemail(email):
-    # type: (str) -> str
+def unescapeSOAemail(email: str) -> str:
     r"""
     Un-escape Email-address from DNS SOA record.
     >>> unescapeSOAemail(r'first\.last.domain.tld')
@@ -149,8 +142,7 @@ def unescapeSOAemail(email):
     raise ValueError()
 
 
-def escapeSOAemail(email):
-    # type: (str) -> str
+def escapeSOAemail(email: str) -> str:
     r"""
     Escape Email-address for DNS SOA record.
     >>> escapeSOAemail('first.last@domain.tld')
@@ -169,8 +161,7 @@ def escapeSOAemail(email):
     return local + '.' + domain
 
 
-def stripDot(old, encoding=()):
-    # type: (list[str] | str | None, tuple[str, ...]) -> str | None
+def stripDot(old: list[str] | str | None, encoding: tuple[str, ...] = ()) -> str | None:
     """
     >>> stripDot(['example.com.', 'example.com'])
     ['example.com', 'example.com']
