@@ -7,8 +7,10 @@
 
 """|UDM| module for |DNS| forward zones"""
 
+from __future__ import annotations
+
 import ipaddress
-from typing import Any  # noqa: F401
+from typing import Any
 
 import univention.admin.filter
 import univention.admin.handlers
@@ -160,13 +162,11 @@ layout = [
 ]
 
 
-def mapMX(old, encoding=()):
-    # type: (list[list[str]], univention.admin.handlers._Encoding) -> list[bytes]
+def mapMX(old: list[list[str]], encoding: univention.admin.handlers._Encoding = ()) -> list[bytes]:
     return [' '.join(entry).encode(*encoding) for entry in old]
 
 
-def unmapMX(old, encoding=()):
-    # type: (list[bytes], univention.admin.handlers._Encoding) -> list[list[str]]
+def unmapMX(old: list[bytes], encoding: univention.admin.handlers._Encoding = ()) -> list[list[str]]:
     return [entry.decode(*encoding).split(' ', 1) for entry in old]
 
 
@@ -183,19 +183,18 @@ class object(univention.admin.handlers.simpleLdap):
 
     def __init__(
         self,
-        co,  # type: None
-        lo,  # type: univention.admin.uldap.access
-        position,  # type: univention.admin.uldap.position | None
-        dn='',  # type: str
-        superordinate=None,  # type: univention.admin.handlers.simpleLdap | None
-        attributes=None,  # type: univention.admin.handlers._Attributes | None
-    ):  # type: (...) -> None
+        co: None,
+        lo: univention.admin.uldap.access,
+        position: univention.admin.uldap.position | None,
+        dn: str = '',
+        superordinate: univention.admin.handlers.simpleLdap | None = None,
+        attributes: univention.admin.handlers._Attributes | None = None,
+    ) -> None:
         univention.admin.handlers.simpleLdap.__init__(self, co, lo, position, dn, superordinate, attributes=attributes)
         if not self.dn and not self.position:
             raise univention.admin.uexceptions.insufficientInformation(_('Neither DN nor position given.'))
 
-    def _post_unmap(self, info, values):
-        # type: (univention.admin.handlers._Properties, univention.admin.handlers._Attributes) -> univention.admin.handlers._Properties
+    def _post_unmap(self, info: univention.admin.handlers._Properties, values: univention.admin.handlers._Attributes) -> univention.admin.handlers._Properties:
         info = super()._post_unmap(info, values)
         info['a'] = []
         if 'aRecord' in values:
@@ -204,8 +203,7 @@ class object(univention.admin.handlers.simpleLdap):
             info['a'] += (ipaddress.IPv6Address(x.decode('ASCII')).exploded for x in values['aAAARecord'])
         return info
 
-    def open(self):
-        # type: () -> None
+    def open(self) -> None:
         univention.admin.handlers.simpleLdap.open(self)
 
         soa = self.oldattr.get('sOARecord', [b''])[0].split(b' ')
@@ -219,12 +217,10 @@ class object(univention.admin.handlers.simpleLdap):
 
         self.save()
 
-    def _ldap_addlist(self):
-        # type: () -> list[tuple[str, Any]]
+    def _ldap_addlist(self) -> list[tuple[str, Any]]:
         return [*super()._ldap_addlist(), ('relativeDomainName', [b'@'])]
 
-    def _ldap_modlist(self):
-        # type: () -> list[tuple[str, Any, Any]]
+    def _ldap_modlist(self) -> list[tuple[str, Any, Any]]:
         ml = univention.admin.handlers.simpleLdap._ldap_modlist(self)
         if self.hasChanged(['nameserver', 'contact', 'serial', 'refresh', 'retry', 'expire', 'ttl']):
             if self['contact'] and not self['contact'].endswith('.'):
@@ -262,16 +258,14 @@ class object(univention.admin.handlers.simpleLdap):
             ml.append(('aAAARecord', oldAaaaRecord, newAaaaRecord))
         return ml
 
-    def _ldap_pre_modify(self):
-        # type: () -> None
+    def _ldap_pre_modify(self) -> None:
         super()._ldap_pre_modify()
         # update SOA record
         if not self.hasChanged('serial'):
             self['serial'] = str(int(self['serial']) + 1)
 
     @classmethod
-    def unmapped_lookup_filter(cls):
-        # type: () -> univention.admin.filter.conjunction
+    def unmapped_lookup_filter(cls) -> univention.admin.filter.conjunction:
         return univention.admin.filter.conjunction('&', [
             univention.admin.filter.expression('objectClass', 'dNSZone'),
             univention.admin.filter.expression('sOARecord', '*', escape=False),
@@ -284,8 +278,7 @@ lookup = object.lookup
 lookup_filter = object.lookup_filter
 
 
-def identify(dn, attr, canonical=False):
-    # type: (str, univention.admin.handlers._Attributes, bool) -> bool
+def identify(dn: str, attr: univention.admin.handlers._Attributes, canonical: bool = False) -> bool:
     return bool(
         is_zone(attr)
         and is_dns(attr)
