@@ -7,6 +7,8 @@
 
 """|UDM| module for groups"""
 
+from __future__ import annotations
+
 import copy
 import time
 from logging import getLogger
@@ -23,7 +25,7 @@ import univention.admin.uldap
 from univention.admin import configRegistry
 from univention.admin.guardian_roles import member_role_layout, member_role_properties, register_member_role_mapping
 from univention.admin.layout import Group, Tab
-from univention.admin.uldap import DN
+from univention.dn import DN
 
 
 log = getLogger('ADMIN')
@@ -260,8 +262,7 @@ class AgingCache:
             type._the_instance = object.__new__(type, *args, **kwargs)
         return type._the_instance
 
-    def __init__(self):
-        # type: () -> None
+    def __init__(self) -> None:
         if '_ready' not in dir(self):
             self._ready = True
             self.timeout = 300
@@ -300,8 +301,7 @@ cache_uniqueMember = AgingCache()
 class object(univention.admin.handlers.simpleLdap):
     module = module
 
-    def open(self):
-        # type: () -> None
+    def open(self) -> None:
         univention.admin.handlers.simpleLdap.open(self)
 
         try:
@@ -311,7 +311,7 @@ class object(univention.admin.handlers.simpleLdap):
             pass
 
         if self.exists():
-            self['memberOf'] = self.lo.searchDn(filter=filter_format('(&(objectClass=posixGroup)(uniqueMember=%s))', [self.dn]))
+            self['memberOf'] = self.lo.authz_connection.searchDn(filter=filter_format('(&(objectClass=posixGroup)(uniqueMember=%s))', [self.dn]))
 
             time_start = time.time()
 
@@ -331,7 +331,7 @@ class object(univention.admin.handlers.simpleLdap):
                     self['users'].append(i)
                     cache_uniqueMember.set(i, {'type': 'user'})
                 else:
-                    result = self.lo.getAttr(i, 'objectClass')
+                    result = self.lo.authz_connection.getAttr(i, 'objectClass')
                     if result:
                         if b'univentionGroup' in result:
                             self['nestedGroup'].append(i)
@@ -355,7 +355,7 @@ class object(univention.admin.handlers.simpleLdap):
         ml = []
         uids = set()
         members = set()
-        searchResult = self.lo.get(self.dn, attr=['uniqueMember', 'memberUid'])
+        searchResult = self.lo.authz_connection.get(self.dn, attr=['uniqueMember', 'memberUid'])
         if searchResult:
             uids = {x.decode('UTF-8').lower() for x in searchResult.get('memberUid', [])}
             members = {x.decode('UTF-8').lower() for x in searchResult.get('uniqueMember', [])}
@@ -371,7 +371,7 @@ class object(univention.admin.handlers.simpleLdap):
 
         if ml:
             try:
-                return self.lo.modify(self.dn, ml)
+                return self.lo.authz_connection.modify(self.dn, ml)
             except ldap.NO_SUCH_OBJECT:
                 raise univention.admin.uexceptions.noObject(self.dn)
             except ldap.INSUFFICIENT_ACCESS:
@@ -386,7 +386,7 @@ class object(univention.admin.handlers.simpleLdap):
         ml = []
         uids = {}
         members = set()
-        searchResult = self.lo.get(self.dn, attr=['uniqueMember', 'memberUid'])
+        searchResult = self.lo.authz_connection.get(self.dn, attr=['uniqueMember', 'memberUid'])
         if searchResult:
             uids = {x.decode('UTF-8').lower(): x.decode('UTF-8') for x in searchResult.get('memberUid', [])}
             members = {x.decode('UTF-8').lower() for x in searchResult.get('uniqueMember', [])}
@@ -402,7 +402,7 @@ class object(univention.admin.handlers.simpleLdap):
         if ml:
             try:
                 try:
-                    return self.lo.modify(self.dn, ml, exceptions=True, ignore_license=ignore_license)
+                    return self.lo.authz_connection.modify(self.dn, ml, exceptions=True, ignore_license=ignore_license)
                 except ldap.NO_SUCH_ATTRIBUTE:
                     # maybe this is the refint overlay:
                     # uniqueMember has already been removed. lets try again, probably with just memberUid...
@@ -419,8 +419,7 @@ class object(univention.admin.handlers.simpleLdap):
         # return True if object has been modified
         return bool(ml)
 
-    def _check_uid_gid_uniqueness(self):
-        # type: () -> None
+    def _check_uid_gid_uniqueness(self) -> None:
         if not configRegistry.is_true("directory/manager/uid_gid/uniqueness", True):
             return
         if "posix" in self.options or "samba" in self.options:
@@ -429,8 +428,7 @@ class object(univention.admin.handlers.simpleLdap):
             if user_objects:
                 raise univention.admin.uexceptions.gidNumberAlreadyUsedAsUidNumber(repr(self["gidNumber"]))
 
-    def _ldap_pre_ready(self):
-        # type: () -> None
+    def _ldap_pre_ready(self) -> None:
         super()._ldap_pre_ready()
 
         # get lock for name
@@ -447,16 +445,14 @@ class object(univention.admin.handlers.simpleLdap):
             except univention.admin.uexceptions.noLock:
                 raise univention.admin.uexceptions.mailAddressUsed(self['mailAddress'])
 
-    def _ldap_pre_create(self):
-        # type: () -> None
+    def _ldap_pre_create(self) -> None:
         super()._ldap_pre_create()
 
         self.request_unique('gidNumber')
         self.check_for_group_recursion()
         self._check_uid_gid_uniqueness()
 
-    def _ldap_pre_modify(self):
-        # type: () -> None
+    def _ldap_pre_modify(self) -> None:
         super()._ldap_pre_modify()
         self.check_for_group_recursion()
         self.check_ad_group_type_change()
@@ -465,8 +461,7 @@ class object(univention.admin.handlers.simpleLdap):
             # this should never happen, as gidNumber is marked as unchangeable
             self._check_uid_gid_uniqueness()
 
-    def _ldap_addlist(self):
-        # type: () -> list
+    def _ldap_addlist(self) -> list:
         al = super()._ldap_addlist()
 
         if 'posix' not in self.options:
@@ -474,8 +469,7 @@ class object(univention.admin.handlers.simpleLdap):
 
         return al
 
-    def _ldap_modlist(self):
-        # type: () -> list
+    def _ldap_modlist(self) -> list:
         ml = univention.admin.handlers.simpleLdap._ldap_modlist(self)
         t1 = time.time()
 
@@ -508,15 +502,16 @@ class object(univention.admin.handlers.simpleLdap):
                 uniqueMemberRemove = uniqueMemberRemove - sameMembers
                 uniqueMemberAdd = uniqueMemberAdd - sameMembers
 
-            def getUidList(uniqueMembers):  # type: (List[DN]) -> List[str]
+            def getUidList(uniqueMembers: list[DN]) -> list[str]:
                 result = []
                 for uniqueMember in uniqueMembers:
                     dn = uniqueMember._dn[0]
-                    try:
-                        result.append([x[1] for x in dn if x[0].lower() == 'uid'][0])  # noqa: RUF015
-                    except IndexError:
+                    member = next((x[1] for x in dn if x[0].lower() == 'uid'), None)
+                    if member is not None:
+                        result.append(member)
+                    else:
                         # UID is not stored in DN --> fetch UID by DN
-                        uid_list = self.lo.getAttr(uniqueMember.dn, 'uid')
+                        uid_list = self.lo.authz_connection.getAttr(uniqueMember.dn, 'uid')
                         # a group have no uid attribute, see Bug #12644
                         if uid_list:
                             result.append(uid_list[0].decode('UTF-8'))
@@ -556,27 +551,24 @@ class object(univention.admin.handlers.simpleLdap):
 
         return ml
 
-    def _ldap_post_create(self):
-        # type: () -> None
+    def _ldap_post_create(self) -> None:
         super()._ldap_post_create()
         self.__update_membership()
 
-    def _ldap_post_modify(self):
-        # type: () -> None
+    def _ldap_post_modify(self) -> None:
         super()._ldap_post_modify()
         self.__update_membership()
         old_sid = self.oldattr.get('sambaSID', [b''])[0].decode('ASCII')
         if self._samba_sid and self._samba_sid != old_sid:
-            for dn, attr in self.lo.search(ldap.filter.filter_format('(sambaPrimaryGroupSID=%s)', [old_sid]), attr=['sambaPrimaryGroupSID']):
-                self.lo.modify(dn, [('sambaPrimaryGroupSID', attr.get('sambaPrimaryGroupSID', []), [self._samba_sid.encode('ASCII')])])
+            for dn, attr in self.lo.authz_connection.search(ldap.filter.filter_format('(sambaPrimaryGroupSID=%s)', [old_sid]), attr=['sambaPrimaryGroupSID']):
+                self.lo.authz_connection.modify(dn, [('sambaPrimaryGroupSID', attr.get('sambaPrimaryGroupSID', []), [self._samba_sid.encode('ASCII')])])
 
-    def _ldap_pre_remove(self):
-        # type: () -> None
+    def _ldap_pre_remove(self) -> None:
         super()._ldap_pre_remove()
         self.open()
         # is this group in mentioned in settings/default?
         try:
-            _dn, attrs = self.lo.search(filter='objectClass=univentionDefault', base=self.position.getDomain(), scope='domain', unique=True, required=True)[0]
+            _dn, attrs = self.lo.authz_connection.search(filter='objectClass=univentionDefault', base=self.position.getDomain(), scope='domain', unique=True, required=True)[0]
         except ldap.NO_SUCH_OBJECT:
             pass
         else:
@@ -588,11 +580,11 @@ class object(univention.admin.handlers.simpleLdap):
         groupSid = None
         if 'posix' in self.old_options:
             gidNum = self.oldattr['gidNumber'][0].decode('ASCII')
-            if self.lo.searchDn(base=self.position.getDomain(), filter=filter_format('(&(objectClass=person)(gidNumber=%s))', [gidNum]), scope='domain'):
+            if self.lo.authz_connection.searchDn(base=self.position.getDomain(), filter=filter_format('(&(objectClass=person)(gidNumber=%s))', [gidNum]), scope='domain'):
                 raise univention.admin.uexceptions.primaryGroupUsed(gidNum)
         if 'samba' in self.old_options:
             groupSid = self.oldattr['sambaSID'][0].decode('ASCII')
-            if self.lo.searchDn(base=self.position.getDomain(), filter=filter_format('(&(objectClass=person)(sambaPrimaryGroupSID=%s))', [groupSid]), scope='domain'):
+            if self.lo.authz_connection.searchDn(base=self.position.getDomain(), filter=filter_format('(&(objectClass=person)(sambaPrimaryGroupSID=%s))', [groupSid]), scope='domain'):
                 raise univention.admin.uexceptions.primaryGroupUsed(groupSid)
         if gidNum:
             self.alloc.append(('gidNumber', gidNum))
@@ -602,13 +594,12 @@ class object(univention.admin.handlers.simpleLdap):
         if self.oldattr.get('mailPrimaryAddress'):
             self.alloc.append(('mailPrimaryAddress', self.oldattr['mailPrimaryAddress'][0].decode('UTF-8')))
 
-    def _ldap_post_remove(self):
-        # type: () -> None
+    def _ldap_post_remove(self) -> None:
         super()._ldap_post_remove()
         for group in self.info.get('memberOf', []):
             if isinstance(group, list):
                 group = group[0]
-            members = [x.decode('UTF-8') for x in self.lo.getAttr(group, 'uniqueMember')]
+            members = [x.decode('UTF-8') for x in self.lo.authz_connection.getAttr(group, 'uniqueMember')]
             if not self.__case_insensitive_in_list(self.dn, members):
                 continue
             newmembers = copy.deepcopy(members)
@@ -616,11 +607,10 @@ class object(univention.admin.handlers.simpleLdap):
             log.debug('groups/group: remove from supergroup %s', group)
             self.__set_membership_attributes(group, members, newmembers)
 
-    def _ldap_post_move(self, olddn):
-        # type: (str) -> None
+    def _ldap_post_move(self, olddn: str) -> None:
         super()._ldap_post_move(olddn)
         settings_module = univention.admin.modules._get('settings/default')
-        settings_object = univention.admin.objects.get(settings_module, None, self.lo, position='', dn='cn=default,cn=univention,%s' % self.lo.base)
+        settings_object = univention.admin.objects.get(settings_module, None, self.lo.authz_connection, position='', dn='cn=default,cn=univention,%s' % self.lo.base, authz=False)
         settings_object.open()
         for attr in ['defaultGroup', 'defaultMemberServerGroup', 'defaultClientGroup', 'defaultDomainControllerMBGroup', 'defaultDomainControllerGroup', 'defaultComputerGroup']:
             if settings_object[attr].lower() == olddn.lower():
@@ -630,7 +620,7 @@ class object(univention.admin.handlers.simpleLdap):
         for group in self.info.get('memberOf', []):
             if isinstance(group, list):
                 group = group[0]
-            members = [x.decode('UTF-8') for x in self.lo.getAttr(group, 'uniqueMember')]
+            members = [x.decode('UTF-8') for x in self.lo.authz_connection.getAttr(group, 'uniqueMember')]
             if not self.__case_insensitive_in_list(olddn, members):
                 continue
             newmembers = copy.deepcopy(members)
@@ -639,8 +629,7 @@ class object(univention.admin.handlers.simpleLdap):
             log.debug('groups/group: updating supergroup %s', group)
             self.__set_membership_attributes(group, members, newmembers)
 
-    def __update_membership(self):
-        # type: () -> None
+    def __update_membership(self) -> None:
         if self.exists():
             old_groups = self.oldinfo.get('memberOf', [])
             old_name = self.oldinfo.get('name', '')
@@ -656,7 +645,7 @@ class object(univention.admin.handlers.simpleLdap):
             for group in self.info.get('memberOf', []):
                 if isinstance(group, list):
                     group = group[0]
-                members = [x.decode('UTF-8') for x in self.lo.getAttr(group, 'uniqueMember')]
+                members = [x.decode('UTF-8') for x in self.lo.authz_connection.getAttr(group, 'uniqueMember')]
                 newmembers = copy.deepcopy(members)
                 newmembers = self.__case_insensitive_remove_from_list(self.old_dn, newmembers)
                 newmembers.append(self.dn)
@@ -676,7 +665,7 @@ class object(univention.admin.handlers.simpleLdap):
         for group in add_to_group:
             if isinstance(group, list):
                 group = group[0]
-            members = [x.decode('UTF-8') for x in self.lo.getAttr(group, 'uniqueMember')]
+            members = [x.decode('UTF-8') for x in self.lo.authz_connection.getAttr(group, 'uniqueMember')]
             if self.__case_insensitive_in_list(self.dn, members):
                 continue
             newmembers = copy.deepcopy(members)
@@ -687,7 +676,7 @@ class object(univention.admin.handlers.simpleLdap):
         for group in remove_from_group:
             if isinstance(group, list):
                 group = group[0]
-            members = [x.decode('UTF-8') for x in self.lo.getAttr(group, 'uniqueMember')]
+            members = [x.decode('UTF-8') for x in self.lo.authz_connection.getAttr(group, 'uniqueMember')]
             newmembers = copy.deepcopy(members)
             if self.__case_insensitive_in_list(self.dn, members):
                 newmembers = self.__case_insensitive_remove_from_list(self.dn, newmembers)
@@ -700,11 +689,11 @@ class object(univention.admin.handlers.simpleLdap):
     def __set_membership_attributes(self, group, members, newmembers):
         members_bytes = [x.encode('UTF-8') for x in members]
         newmembers_bytes = [x.encode('UTF-8') for x in newmembers]
-        self.lo.modify(group, [('uniqueMember', members_bytes, newmembers_bytes)])
+        self.lo.authz_connection.modify(group, [('uniqueMember', members_bytes, newmembers_bytes)])
         # don't set the memberUid attribute for nested groups, see Bug #11868
-        # uids = self.lo.getAttr( group, 'memberUid' )
+        # uids = self.lo.authz_connection.getAttr( group, 'memberUid' )
         # newuids = map(lambda x: x[x.find('=') + 1: x.find(',')], newmembers)
-        # self.lo.modify( group, [ ( 'memberUid', uids, newuids ) ] )
+        # self.lo.authz_connection.modify( group, [ ( 'memberUid', uids, newuids ) ] )
 
     @staticmethod
     def __case_insensitive_in_list(dn, members):
@@ -715,8 +704,7 @@ class object(univention.admin.handlers.simpleLdap):
         dn_lower = dn.lower()
         return [x for x in members if x.lower() != dn_lower]
 
-    def check_for_group_recursion(self):
-        # type: () -> None
+    def check_for_group_recursion(self) -> None:
         # perform check only if membership of groups has changed
         if not self.hasChanged('memberOf') and not self.hasChanged('nestedGroup'):
             return
@@ -742,7 +730,7 @@ class object(univention.admin.handlers.simpleLdap):
         set_memberOf = {x.lower() for x in self.info.get('memberOf', [])}
         set_intersection = set_nestedGroup & set_memberOf
         if set_intersection:
-            childdn = list(set_intersection)[0]  # noqa: RUF015
+            childdn = next(iter(set_intersection))
             # get cn for first detected object
             childobj = univention.admin.objects.get(grp_module, self.co, self.lo, position='', dn=childdn)
             childcn = childobj.info.get('name', 'UNKNOWN')
@@ -785,61 +773,53 @@ class object(univention.admin.handlers.simpleLdap):
 
             self._check_group_childs_for_recursion(grp_module, grpdn2childgrpdns, childgrp.lower(), new_parents)
 
-    def __is_groupType_universal(self, adGroupType):
-        # type: (bytes) -> int
+    def __is_groupType_universal(self, adGroupType: bytes) -> int:
         try:
             return int(adGroupType) & 0x8
         except ValueError:
             return False
 
-    def __is_groupType_global(self, adGroupType):
-        # type: (bytes) -> int
+    def __is_groupType_global(self, adGroupType: bytes) -> int:
         try:
             return int(adGroupType) & 0x2
         except ValueError:
             return False
 
-    def __is_groupType_domain_local(self, adGroupType):
-        # type: (bytes) -> int
+    def __is_groupType_domain_local(self, adGroupType: bytes) -> int:
         try:
             return int(adGroupType) & 0x4
         except ValueError:
             return False
 
-    def __is_groupType_local(self, adGroupType):
-        # type: (bytes) -> int
+    def __is_groupType_local(self, adGroupType: bytes) -> int:
         try:
             return int(adGroupType) & 0x1
         except ValueError:
             return False
 
-    def _is_global_member(self):
-        # type: () -> bool
-        searchResult = self.lo.search(base=self.position.getDomain(), filter=filter_format('(uniqueMember=%s)', [self.dn]), attr=['univentionGroupType'])
+    def _is_global_member(self) -> bool:
+        searchResult = self.lo.authz_connection.search(base=self.position.getDomain(), filter=filter_format('(uniqueMember=%s)', [self.dn]), attr=['univentionGroupType'])
         for (_dn, attr) in searchResult:
             groupType = attr.get('univentionGroupType', [None])[0]
             if self.__is_groupType_global(groupType):
                 return True
         return False
 
-    def _has_domain_local_member(self):
-        # type: () -> bool
+    def _has_domain_local_member(self) -> bool:
         for member_dn in [x.decode('UTF-8') for x in self.oldattr.get('uniqueMember', [])]:
-            searchResult = self.lo.getAttr(member_dn, 'univentionGroupType')
+            searchResult = self.lo.authz_connection.getAttr(member_dn, 'univentionGroupType')
             if searchResult and self.__is_groupType_domain_local(searchResult[0]):
                 return True
         return False
 
-    def _has_universal_member(self):
-        # type: () -> bool
+    def _has_universal_member(self) -> bool:
         for member_dn in [x.decode('UTF-8') for x in self.oldattr.get('uniqueMember', [])]:
-            searchResult = self.lo.getAttr(member_dn, 'univentionGroupType')
+            searchResult = self.lo.authz_connection.getAttr(member_dn, 'univentionGroupType')
             if searchResult and self.__is_groupType_universal(searchResult[0]):
                 return True
         return False
 
-    def check_ad_group_type_change(self):
-        # type: () -> None
+    def check_ad_group_type_change(self) -> None:
         if not self.hasChanged('adGroupType'):
             return
 
@@ -885,7 +865,7 @@ class object(univention.admin.handlers.simpleLdap):
                 raise univention.admin.uexceptions.adGroupTypeChangeUniversalToGlobal
 
     def __allocate_rid(self, rid):
-        searchResult = self.lo.search(filter='objectClass=sambaDomain', attr=['sambaSID'])
+        searchResult = self.lo.authz_connection.search(filter='objectClass=sambaDomain', attr=['sambaSID'])
         new_groupType = self.info.get('adGroupType', 0)
         if self.__is_groupType_local(new_groupType):
             sid = 'S-1-5-32-' + self['sambaRID']
