@@ -7,6 +7,8 @@
 
 """|UDM| module for mail IMAP folders"""
 
+from __future__ import annotations
+
 from logging import getLogger
 
 import ldap
@@ -123,8 +125,7 @@ class object(univention.admin.handlers.simpleLdap):
     def _get_admin_diary_args(self, event):
         return {'module': self.module, 'nameWithMailDomain': self.description()}
 
-    def _post_unmap(self, oldinfo, oldattr):
-        # type: (univention.admin.handlers._Properties, univention.admin.handlers._Attributes) -> univention.admin.handlers._Properties
+    def _post_unmap(self, oldinfo: univention.admin.handlers._Properties, oldattr: univention.admin.handlers._Attributes) -> univention.admin.handlers._Properties:
         cn = oldattr.get('cn', [b''])[0].decode('UTF-8')
         if cn:
             oldinfo['name'], oldinfo['mailDomain'] = cn.split('@', 1)
