@@ -7,6 +7,7 @@
 
 """|UDM| module for all setting objects"""
 
+from __future__ import annotations
 
 import univention.admin
 import univention.admin.filter
@@ -31,8 +32,8 @@ object_name_plural = _('Preferences')
 long_description = ''
 operations = ['search']
 virtual = True
-options = {}  # type: dict[str, univention.admin.option]
-property_descriptions = {}  # type: dict[str, univention.admin.property]
+options: dict[str, univention.admin.option] = {}
+property_descriptions: dict[str, univention.admin.property] = {}
 
 mapping = univention.admin.mapping.mapping()
 
@@ -41,8 +42,7 @@ class object(univention.admin.handlers.simpleLdap):
     module = module
 
 
-def lookup(co, lo, filter_s, base='', superordinate=None, scope='sub', unique=False, required=False, timeout=-1, sizelimit=0):
-    # type: (None, univention.admin.uldap.access, str, str, univention.admin.handlers.simpleLdap | None, str, bool, bool, int, int) -> list[univention.admin.handlers.simpleLdap]
+def lookup(co: None, lo: univention.admin.uldap.access, filter_s: str, base: str = '', superordinate: univention.admin.handlers.simpleLdap | None = None, scope: str = 'sub', unique: bool = False, required: bool = False, timeout: int = -1, sizelimit: int = 0) -> list[univention.admin.handlers.simpleLdap]:
     return [
         obj
         for mod in (univention.admin.handlers.settings.directory, univention.admin.handlers.settings.default, univention.admin.handlers.settings.usertemplate, univention.admin.handlers.settings.license)
@@ -50,6 +50,5 @@ def lookup(co, lo, filter_s, base='', superordinate=None, scope='sub', unique=Fa
     ]
 
 
-def identify(dn, attr, canonical=False):
-    # type: (str, univention.admin.handlers._Attributes, bool) -> None
+def identify(dn: str, attr: univention.admin.handlers._Attributes, canonical: bool = False) -> None:
     pass
