@@ -7,6 +7,8 @@
 
 """|UDM| module for |UDM| hooks"""
 
+from __future__ import annotations
+
 import apt
 
 import univention.admin.filter
@@ -145,8 +147,7 @@ class object(univention.admin.handlers.simpleLdap):
             if not apt.apt_pkg.version_compare(self['packageversion'], old_version) > -1:
                 raise univention.admin.uexceptions.valueInvalidSyntax(_('packageversion: Version must not be lower than the current one.'), property='packageversion')
 
-    def _post_unmap(self, info, values):
-        # type: (univention.admin.handlers._Properties, univention.admin.handlers._Attributes) -> univention.admin.handlers._Properties
+    def _post_unmap(self, info: univention.admin.handlers._Properties, values: univention.admin.handlers._Attributes) -> univention.admin.handlers._Properties:
         info['messagecatalog'] = []
         messagecatalog_ldap_attribute = "univentionMessageCatalog"
         messagecatalog_ldap_attribute_and_tag_prefix = "%s;entry-lang-" % (messagecatalog_ldap_attribute,)
