@@ -14,6 +14,8 @@ import copy
 import importlib
 import locale
 import os
+import traceback
+import warnings
 from importlib import reload as reload_module
 from logging import getLogger
 from typing import TYPE_CHECKING, Any, Protocol, overload
@@ -66,7 +68,7 @@ class UdmModule(Protocol):
         pass
 
     @staticmethod
-    def lookup(co: None, lo: univention.admin.uldap.access, filter: str = '', base: str = '', superordinate: Any = None, scope: str = 'base+one', unique: bool = False, required: bool = False, timeout: int = -1, sizelimit: int = 0) -> list[Any]:
+    def lookup(co: None, lo: univention.admin.uldap.access, filter: str = '', base: str = '', superordinate: Any = None, scope: str = 'base+one', unique: bool = False, required: bool = False, timeout: int = -1, sizelimit: int = 0, authz: bool = True) -> list[Any]:
         pass
 
     @staticmethod
@@ -90,7 +92,7 @@ containers: list[UdmModule] = []
 
 @univention.admin._ldap_cache(ttl=3600)
 def _ldap_operational_attribute_names(lo: univention.admin.uldap.access) -> set[str]:
-    schema = lo.get_schema()
+    schema = lo.authz_connection.get_schema()
     attrs = [schema.get_obj(ldap.schema.models.AttributeType, x) for x in schema.listall(ldap.schema.models.AttributeType)]
     usages = [ldap.schema.models.AttributeUsage[o] for o in ('directoryoperation', 'dsaoperation', 'distributedoperation')]
     return {n.lower() for a in attrs for n in a.names if a.usage in usages}
@@ -185,6 +187,12 @@ def init(lo: univention.admin.uldap.access, position: univention.admin.uldap.pos
     :param template_object: Reference to a instance, from which the default values are used.
     :param force_reload: With `True` force Python to reload the module from the file system.
     """
+    if isinstance(lo, univention.uldap.access):
+        log.error('Wrong access class in use! Use univention.admin.uldap instead of univention.uldap! %s', ''.join(traceback.format_stack()))
+        warnings.warn('Wrong access class in use! Use univention.admin.uldap instead of univention.uldap!', DeprecationWarning, stacklevel=3)
+        if configRegistry.is_true('directory/mananger/type-checking/strict'):
+            raise TypeError('Expect univention.admin.uldap.access!')
+
     # you better do a reload if init is called a second time
     # especially because update_extended_attributes
     # called twice will have side-effects
@@ -257,7 +265,7 @@ def update_extended_options(lo: univention.admin.uldap.access, module: UdmModule
 
     # append UDM extended options
     new_options = copy.copy(module.options) if hasattr(module, 'options') else {}
-    for _dn, attrs in lo.search(base=position.getDomainConfigBase(), filter='(&(objectClass=univentionUDMOption)%s)' % (module_filter,)):
+    for _dn, attrs in lo.authz_connection.search(base=position.getDomainConfigBase(), filter='(&(objectClass=univentionUDMOption)%s)' % (module_filter,)):
         oname = attrs['cn'][0].decode('UTF-8', 'replace')
         shortdesc = _get_translation(lang, attrs, 'univentionUDMOptionTranslationShortDescription;entry-%s', 'univentionUDMOptionShortDescription')
         longdesc = _get_translation(lang, attrs, 'univentionUDMOptionTranslationLongDescription;entry-%s', 'univentionUDMOptionLongDescription')
@@ -272,7 +280,8 @@ def update_extended_options(lo: univention.admin.uldap.access, module: UdmModule
             default=default,
             editable=editable,
             objectClasses=classes,
-            is_app_option=is_app_option)
+            is_app_option=is_app_option,
+        )
     module.options = new_options
 
 
@@ -352,7 +361,7 @@ def update_extended_attributes(lo: univention.admin.uldap.access, module: UdmMod
         module_filter = '(|(univentionUDMPropertyModule=users/user)%s)' % (module_filter,)
 
     new_property_descriptions = copy.copy(module.property_descriptions)
-    for _dn, attrs in lo.search(base=position.getDomainConfigBase(), filter='(&(objectClass=univentionUDMProperty)%s(univentionUDMPropertyVersion=2))' % (module_filter,)):
+    for _dn, attrs in lo.authz_connection.search(base=position.getDomainConfigBase(), filter='(&(objectClass=univentionUDMProperty)%s(univentionUDMPropertyVersion=2))' % (module_filter,)):
         # get CLI name
         pname = attrs['univentionUDMPropertyCLIName'][0].decode('UTF-8', 'replace')
         object_class = attrs.get('univentionUDMPropertyObjectClass', [])[0].decode('UTF-8', 'replace')
@@ -365,7 +374,7 @@ def update_extended_attributes(lo: univention.admin.uldap.access, module: UdmMod
         if propertySyntaxString and hasattr(univention.admin.syntax, propertySyntaxString):
             propertySyntax = getattr(univention.admin.syntax, propertySyntaxString)
         else:
-            if lo.searchDn(filter=filter_format(univention.admin.syntax.LDAP_Search.FILTER_PATTERN, [propertySyntaxString])):
+            if lo.authz_connection.searchDn(filter=filter_format(univention.admin.syntax.LDAP_Search.FILTER_PATTERN, [propertySyntaxString])):
                 propertySyntax = univention.admin.syntax.LDAP_Search(propertySyntaxString)
             else:
                 propertySyntax = univention.admin.syntax.string()
@@ -742,7 +751,7 @@ def find_superordinate(dn: str, co: None, lo: univention.admin.uldap.access) ->
     """
     # walk up the ldap path and stop if we find an object type that is a superordinate
     while dn:
-        attr = lo.get(dn)
+        attr = lo.authz_connection.get(dn)  # TODO: information disclosure?
         module = identifyOne(dn, attr)
         if module and isSuperordinate(module):
             return get(module)
@@ -883,7 +892,7 @@ def virtual(module_name: UdmName) -> bool:
     return getattr(module, 'virtual', False)
 
 
-def lookup(module_name: UdmName, co: None, lo: univention.admin.uldap.access, filter: str = '', base: str = '', superordinate: Any = None, scope: str = 'base+one', unique: bool = False, required: bool = False, timeout: int = -1, sizelimit: int = 0) -> list[Any]:
+def lookup(module_name: UdmName, co: None, lo: univention.admin.uldap.access, filter: str = '', base: str = '', superordinate: Any = None, scope: str = 'base+one', unique: bool = False, required: bool = False, timeout: int = -1, sizelimit: int = 0, authz: bool = True) -> list[Any]:
     """
     Return objects of module that match the given criteria.
 
@@ -893,7 +902,8 @@ def lookup(module_name: UdmName, co: None, lo: univention.admin.uldap.access, fi
     tmpres = []
 
     if hasattr(module, 'lookup'):
-        tmpres = module.lookup(co, lo, filter, base=base, superordinate=superordinate, scope=scope, unique=unique, required=required, timeout=timeout, sizelimit=sizelimit)
+        kw = {} if authz else {'authz': authz}  # TODO: not every UDM module supports the new parameter
+        tmpres = module.lookup(co, lo, filter, base=base, superordinate=superordinate, scope=scope, unique=unique, required=required, timeout=timeout, sizelimit=sizelimit, **kw)
 
     # check for 'None' items just in case...
     return [item for item in tmpres if item]
@@ -965,7 +975,7 @@ def objectType(co: None, lo: univention.admin.uldap.access, dn: str, attr: _Attr
     if not dn:
         return []
     if attr is None:
-        attr = lo.get(dn)
+        attr = lo.authz_connection.get(dn)  # TODO: information disclosure?
         if not attr:
             return []
     ot = attr.get('univentionObjectType')
@@ -988,7 +998,7 @@ def objectShadowType(co: None, lo: univention.admin.uldap.access, dn: str, attr:
 
 def findObject(co: None, lo: univention.admin.uldap.access, dn: str, type: UdmModule, attr: _Attributes | None = None, module_base: str | None = None) -> Any | None:
     if attr is None:
-        attr = lo.get(dn)
+        attr = lo.authz_connection.get(dn)  # TODO: information disclosure?
         if not attr:
             return None
     ndn = dn
@@ -1002,7 +1012,7 @@ def findObject(co: None, lo: univention.admin.uldap.access, dn: str, type: UdmMo
         ndn = lo.parentDn(ndn)
         if not ndn:
             break
-        nattr = lo.get(ndn)
+        nattr = lo.authz_connection.get(ndn)  # TODO: information disclosure?
     return None
 
 
