@@ -7,9 +7,10 @@
 
 """|UDM| objects."""
 
+from __future__ import annotations
 
 from logging import getLogger
-from typing import Any  # noqa: F401
+from typing import Any
 
 import ldap
 
@@ -19,8 +20,7 @@ import univention.admin.modules
 log = getLogger('ADMIN')
 
 
-def module(object):
-    # type: (univention.admin.handlers.simpleLdap) -> str | None
+def module(object: univention.admin.handlers.simpleLdap) -> str | None:
     """
     Return handler name for |UDM| object.
 
@@ -30,8 +30,7 @@ def module(object):
     return getattr(object, 'module', None)
 
 
-def get_superordinate(module, co, lo, dn):
-    # type: (univention.admin.modules.UdmModule, None, univention.admin.uldap.access, str) -> univention.admin.handlers.simpleLdap | None
+def get_superordinate(module: univention.admin.modules.UdmModule, co: None, lo: univention.admin.uldap.access, dn: str) -> univention.admin.handlers.simpleLdap | None:
     """
     Searches for the superordinate object for the given DN.
 
@@ -44,20 +43,18 @@ def get_superordinate(module, co, lo, dn):
     super_modules = set(univention.admin.modules.superordinate_names(module))
     if super_modules:
         while dn:
-            attr = lo.get(dn)
-            modules = {univention.admin.modules.name(x) for x in univention.admin.modules.identify(dn, attr)} & super_modules
-            if modules:
-                super_module = univention.admin.modules._get(list(modules)[0])  # noqa: RUF015
-                return get(super_module, co, lo, None, dn)
+            attr = lo.authz_connection.get(dn)
+            for module in {univention.admin.modules.name(x) for x in univention.admin.modules.identify(dn, attr)} & super_modules:
+                super_module = univention.admin.modules._get(module)
+                return get(super_module, co, lo, None, dn, authz='settings/cn' != super_module)
             dn = lo.parentDn(dn)
 
     return None
 
 
-def get(module, co, lo, position, dn='', attr=None, superordinate=None, attributes=None):
-    # type: (univention.admin.modules.UdmModule, None, univention.admin.uldap.access, univention.admin.uldap.position, str, dict[str, list[Any]] | None, Any | None, Any | None) -> univention.admin.handlers.simpleLdap | None
+def get(module: univention.admin.modules.UdmModule, co: None, lo: univention.admin.uldap.access, position: univention.admin.uldap.position, dn: str = '', attr: dict[str, list[Any]] | None = None, superordinate: Any | None = None, attributes: Any | None = None, authz: bool = True) -> univention.admin.handlers.simpleLdap | None:
     """
-    Return object of module while trying to create objects of
+    Return object of module while trying to identify objects of
     superordinate modules as well.
 
     :param module: |UDM| handler.
@@ -74,11 +71,11 @@ def get(module, co, lo, position, dn='', attr=None, superordinate=None, attribut
 
     if dn:
         try:
-            obj = univention.admin.modules.lookup(module.module, co, lo, base=dn, superordinate=superordinate, scope='base', unique=True, required=True)[0]
+            obj = univention.admin.modules.lookup(module.module, co, lo, base=dn, superordinate=superordinate, scope='base', unique=True, required=True, authz=authz)[0]
             obj.position.setDn(position.getDn() if position else dn)
             return obj
-        except (ldap.NO_SUCH_OBJECT, univention.admin.uexceptions.noObject):
-            if not lo.get(dn, attr=['objectClass']):
+        except (ldap.NO_SUCH_OBJECT, univention.admin.uexceptions.noObject, IndexError):
+            if not lo.authz_connection.get(dn, attr=['objectClass']):  # FIXME: information disclosure
                 raise univention.admin.uexceptions.noObject(dn)
             if not univention.admin.modules.virtual(module.module):
                 raise univention.admin.uexceptions.wrongObjectType('The object %s is not a %s.' % (dn, module.module))
@@ -86,8 +83,22 @@ def get(module, co, lo, position, dn='', attr=None, superordinate=None, attribut
     return module.object(co, lo, position, dn, superordinate=superordinate, attributes=attributes)
 
 
-def open(object):
-    # type: (univention.admin.handlers.simpleLdap) -> None
+def get_object(lo: univention.admin.uldap.access, dn: str) -> univention.admin.handlers.simpleLdap:
+    """
+    Get a |UDM| object for the specified LDAP DN by automatically detecting the object type.
+    Returns `None` if the object doesn't exists or no |UDM| handler exists for it.
+
+    :param lo: |LDAP| connection.
+    :param dn: |DN| of the object.
+    """
+    attr = lo.authz_connection.get(dn, ['*', '+'])
+    for modname in univention.admin.modules.objectType(None, lo, dn, attr):
+        module = univention.admin.modules.get(modname)
+        if module:
+            return module.object(None, lo, None, dn, None, attr)
+
+
+def open(object: univention.admin.handlers.simpleLdap) -> None:
     """
     Initialization of properties not necessary for browsing etc.
 
@@ -100,8 +111,7 @@ def open(object):
         object.open()
 
 
-def default(module, co, lo, position):
-    # type: (univention.admin.modules.UdmModule, None, univention.admin.uldap.access, univention.admin.uldap.position) -> univention.admin.handlers.simpleLdap
+def default(module: univention.admin.modules.UdmModule, co: None, lo: univention.admin.uldap.access, position: univention.admin.uldap.position) -> univention.admin.handlers.simpleLdap:
     """
     Create |UDM| object and initialize default values.
 
@@ -120,8 +130,7 @@ def default(module, co, lo, position):
     return object
 
 
-def description(object):
-    # type: (univention.admin.handlers.simpleLdap) -> str
+def description(object: univention.admin.handlers.simpleLdap) -> str:
     """
     Return short description for object.
 
@@ -130,8 +139,7 @@ def description(object):
     return object.description()
 
 
-def shadow(lo, module, object, position):
-    # type: (univention.admin.uldap.access, univention.admin.modules.UdmModule, univention.admin.handlers.simpleLdap, univention.admin.uldap.position) -> tuple[univention.admin.handlers.simpleLdap, univention.admin.modules.UdmModule] | tuple[None, None]
+def shadow(lo: univention.admin.uldap.access, module: univention.admin.modules.UdmModule, object: univention.admin.handlers.simpleLdap, position: univention.admin.uldap.position) -> tuple[univention.admin.handlers.simpleLdap, univention.admin.modules.UdmModule] | tuple[None, None]:
     """
     If object is a container, return object and module the container
     shadows (that is usually the one that is subordinate in the LDAP tree).
@@ -150,7 +158,7 @@ def shadow(lo, module, object, position):
         dn = lo.parentDn(dn)
         if not dn:
             return (None, None)
-        attr = lo.get(dn)
+        attr = lo.authz_connection.get(dn)  # TODO: information disclosure?
         for m in univention.admin.modules.identify(dn, attr):
             if not univention.admin.modules.isContainer(m):
                 o = get(m, None, lo, position=position, dn=dn)
@@ -159,8 +167,7 @@ def shadow(lo, module, object, position):
     return (module, object)
 
 
-def dn(object):
-    # type: (univention.admin.handlers.simpleLdap) -> str | None
+def dn(object: univention.admin.handlers.simpleLdap) -> str | None:
     """
     Return the |DN| of the object.
 
@@ -170,8 +177,7 @@ def dn(object):
     return getattr(object, 'dn', None)
 
 
-def ocToType(oc):
-    # type: (str) -> str | None
+def ocToType(oc: str) -> str | None:
     """
     Return the |UDM| module capabale of handling the given |LDAP| objectClass.
 
@@ -184,8 +190,7 @@ def ocToType(oc):
     return None  # FIXME:
 
 
-def fixedAttribute(object, key):
-    # type: (univention.admin.handlers.simpleLdap, str) -> int
+def fixedAttribute(object: univention.admin.handlers.simpleLdap, key: str) -> int:
     """
     Check if the named property is a fixed attribute (not overwritten by more specific policies).
 
@@ -199,8 +204,7 @@ def fixedAttribute(object, key):
     return object.fixedAttributes().get(key, False)
 
 
-def emptyAttribute(object, key):
-    # type: (univention.admin.handlers.simpleLdap, str) -> int
+def emptyAttribute(object: univention.admin.handlers.simpleLdap, key: str) -> int:
     """
     Check if the named property is an empty attribute (reset to empty by a general policy).
 
@@ -214,8 +218,7 @@ def emptyAttribute(object, key):
     return object.emptyAttributes().get(key, False)
 
 
-def getPolicyReference(object, policy_type):
-    # type: (univention.admin.handlers.simpleLdap, str) -> univention.admin.handlers.simplePolicy | None
+def getPolicyReference(object: univention.admin.handlers.simpleLdap, policy_type: str) -> univention.admin.handlers.simplePolicy | None:
     """
     Return the policy of the requested type.
 
@@ -227,15 +230,14 @@ def getPolicyReference(object, policy_type):
 
     policyReference = None
     for policy_dn in object.policies:
-        for m in univention.admin.modules.identify(policy_dn, object.lo.get(policy_dn)):
+        for m in univention.admin.modules.identify(policy_dn, object.lo.authz_connection.get(policy_dn)):
             if univention.admin.modules.name(m) == policy_type:
                 policyReference = policy_dn
     log.debug('getPolicyReference: returning: %s', policyReference)
     return policyReference
 
 
-def removePolicyReference(object, policy_type):
-    # type: (univention.admin.handlers.simpleLdap, str) -> None
+def removePolicyReference(object: univention.admin.handlers.simpleLdap, policy_type: str) -> None:
     """
     Remove the policy of the requested type.
 
@@ -246,7 +248,7 @@ def removePolicyReference(object, policy_type):
 
     remove = None
     for policy_dn in object.policies:
-        for m in univention.admin.modules.identify(policy_dn, object.lo.get(policy_dn)):
+        for m in univention.admin.modules.identify(policy_dn, object.lo.authz_connection.get(policy_dn)):
             if univention.admin.modules.name(m) == policy_type:
                 remove = policy_dn
     if remove:
@@ -254,8 +256,7 @@ def removePolicyReference(object, policy_type):
         object.policies.remove(remove)
 
 
-def replacePolicyReference(object, policy_type, new_reference):
-    # type: (univention.admin.handlers.simpleLdap, str, univention.admin.handlers.simplePolicy) -> None
+def replacePolicyReference(object: univention.admin.handlers.simpleLdap, policy_type: str, new_reference: univention.admin.handlers.simplePolicy) -> None:
     """
     Replace the policy of the requested type with a new instance.
 
@@ -265,7 +266,7 @@ def replacePolicyReference(object, policy_type, new_reference):
     # FIXME: Move this to handlers.simpleLdap?
 
     module = univention.admin.modules._get(policy_type)
-    if not univention.admin.modules.recognize(module, new_reference, object.lo.get(new_reference)):
+    if not univention.admin.modules.recognize(module, new_reference, object.lo.authz_connection.get(new_reference)):
         log.debug('replacePolicyReference: error.')
         return
 
@@ -275,8 +276,7 @@ def replacePolicyReference(object, policy_type, new_reference):
     object.policies.append(new_reference)
 
 
-def restorePolicyReference(object, policy_type):
-    # type: (univention.admin.handlers.simpleLdap, str) -> None
+def restorePolicyReference(object: univention.admin.handlers.simpleLdap, policy_type: str) -> None:
     """
     Restore the policy of the requested type.
 
@@ -293,14 +293,13 @@ def restorePolicyReference(object, policy_type):
 
     restore = None
     for policy_dn in object.oldpolicies:
-        if univention.admin.modules.recognize(module, policy_dn, object.lo.get(policy_dn)):
+        if univention.admin.modules.recognize(module, policy_dn, object.lo.authz_connection.get(policy_dn)):
             restore = policy_dn
     if restore:
         object.policies.append(restore)
 
 
-def wantsCleanup(object):
-    # type: (univention.admin.handlers.simpleLdap) -> bool
+def wantsCleanup(object: univention.admin.handlers.simpleLdap) -> bool:
     """
     Check if the given object wants to perform a cleanup (delete
     other objects, etc.) before it is deleted itself.
@@ -319,8 +318,7 @@ def wantsCleanup(object):
     return wantsCleanup
 
 
-def performCleanup(object):
-    # type: (univention.admin.handlers.simpleLdap) -> None
+def performCleanup(object: univention.admin.handlers.simpleLdap) -> None:
     """
     some objects create other objects. remove those if necessary.
 
