@@ -7,10 +7,11 @@
 
 """|UDM| wrapper around :py:mod:`univention.uldap` that replaces exceptions."""
 
+from __future__ import annotations
 
 import time
-from collections.abc import Callable  # noqa: F401
 from logging import getLogger
+from typing import TYPE_CHECKING
 
 import ldap
 
@@ -18,8 +19,15 @@ import univention.admin.license
 import univention.uldap
 from univention.admin import localization
 from univention.admin._ucr import configRegistry
+from univention.dn import DN
 
 
+if TYPE_CHECKING:
+    from collections.abc import Callable
+    from typing import Any
+
+__all__ = ('DN', 'access', 'domain', 'explodeDn', 'getAdminConnection', 'getBaseDN', 'getMachineConnection', 'position')
+
 udm_log = getLogger('ADMIN')
 log = getLogger('LDAP')
 
@@ -29,85 +37,7 @@ _ = translation.translate
 explodeDn = univention.uldap.explodeDn
 
 
-class DN:
-    """A |LDAP| Distinguished Name."""
-
-    def __init__(self, dn):
-        # type: (str) -> None
-        self.dn = dn
-        self._hash = None
-        self._str = None
-        try:
-            self._dn = ldap.dn.str2dn(self.dn)
-        except ldap.DECODING_ERROR:
-            raise ValueError('Malformed DN syntax: %r' % (self.dn,))
-
-    def __str__(self):
-        # compute string only once since the object is static
-        if self._str is None:
-            self._str = ldap.dn.dn2str(self._dn)
-        return self._str
-
-    def __unicode__(self):  # noqa: PLW3201
-        return unicode(str(self))  # noqa: F821
-
-    def __repr__(self):
-        return '<%s %r>' % (type(self).__name__, str(self))
-
-    def __eq__(self, other):
-        """
-        >>> DN('foo=1') == DN('foo=1')
-        True
-        >>> DN('foo=1') == DN('foo=2')
-        False
-        >>> DN('Foo=1') == DN('foo=1')
-        True
-        >>> DN('Foo=1') == DN('foo=2')
-        False
-        >>> DN('foo=1,bar=2') == DN('foo=1,bar=2')
-        True
-        >>> DN('bar=2,foo=1') == DN('foo=1,bar=2')
-        False
-        >>> DN('foo=1+bar=2') == DN('foo=1+bar=2')
-        True
-        >>> DN('bar=2+foo=1') == DN('foo=1+bar=2')
-        True
-        >>> DN('bar=2+Foo=1') == DN('foo=1+Bar=2')
-        True
-        >>> DN(r'foo=%s31' % chr(92)) == DN(r'foo=1')
-        True
-        """
-        return hash(self) == hash(other)
-
-    def __ne__(self, other):
-        return not self == other
-
-    def __hash__(self):
-        # compute hash only once - object is static
-        # TODO: attributes which's values are case insensitive should be respected
-        if self._hash is None:
-            self._hash = hash(tuple(tuple(sorted((x.lower(), y, z) for x, y, z in rdn)) for rdn in self._dn))
-        return self._hash
-
-    @classmethod
-    def set(cls, values):
-        """
-        >>> len(DN.set(['CN=computers,dc=foo', 'cn=computers,dc=foo', 'cn = computers,dc=foo']))
-        1
-        """
-        return set(map(cls, values))
-
-    @classmethod
-    def values(cls, values):
-        """
-        >>> DN.values(DN.set(['cn=foo', 'cn=bar']) - DN.set(['cn = foo'])) == {'cn=bar'}
-        True
-        """
-        return set(map(str, values))
-
-
-def getBaseDN(host='localhost', port=None, uri=None):
-    # type: (str, int | None, str | None) -> str
+def getBaseDN(host: str = 'localhost', port: int | None = None, uri: str | None = None) -> str:
     """
     Return the naming context of the LDAP server.
 
@@ -131,8 +61,7 @@ def getBaseDN(host='localhost', port=None, uri=None):
     return result[0][1]['namingContexts'][0].decode('utf-8')
 
 
-def getAdminConnection(start_tls=None, decode_ignorelist=None):
-    # type: (int | None, None) -> tuple[univention.admin.uldap.access, univention.admin.uldap.position]
+def getAdminConnection(start_tls: int | None = None, decode_ignorelist: None = None) -> tuple[univention.admin.uldap.access, univention.admin.uldap.position]:
     """
     Open a LDAP connection using the admin credentials.
 
@@ -144,8 +73,7 @@ def getAdminConnection(start_tls=None, decode_ignorelist=None):
     return access(lo=lo), pos
 
 
-def getMachineConnection(start_tls=None, decode_ignorelist=None, ldap_master=True):
-    # type: (int | None, None, bool) -> tuple[univention.admin.uldap.access, univention.admin.uldap.position]
+def getMachineConnection(start_tls: int | None = None, decode_ignorelist: None = None, ldap_master: bool = True) -> tuple[univention.admin.uldap.access, univention.admin.uldap.position]:
     """
     Open a LDAP connection using the machine credentials.
 
@@ -158,8 +86,7 @@ def getMachineConnection(start_tls=None, decode_ignorelist=None, ldap_master=Tru
     return access(lo=lo), pos
 
 
-def _err2str(err):
-    # type: (Exception) -> str
+def _err2str(err: Exception) -> str:
     """
     Convert exception arguments to string.
 
@@ -182,18 +109,16 @@ def _err2str(err):
 class domain:
     """A |UDM| domain name."""
 
-    def __init__(self, lo, position):
-        # type: (univention.admin.uldap.access, univention.admin.uldap.position) -> None
+    def __init__(self, lo: univention.admin.uldap.access, position: univention.admin.uldap.position) -> None:
         """
         :param univention.admin.uldap.access lo: A LDAP connection object.
         :param univention.admin.uldap.position position: A UDM position specifying the LDAP base container.
         """
         self.lo = lo
         self.position = position
-        self.domain = self.lo.get(self.position.getDomain(), attr=['sambaDomain', 'sambaSID', 'krb5RealmName'])
+        self.domain = self.lo.authz_connection.get(self.position.getDomain(), attr=['sambaDomain', 'sambaSID', 'krb5RealmName'])
 
-    def getKerberosRealm(self):
-        # type: () -> str | None
+    def getKerberosRealm(self) -> str | None:
         """
         Return the name of the Kerberos realms.
 
@@ -210,8 +135,7 @@ class position:
     Supports relative distinguished names.
     """
 
-    def __init__(self, base, loginDomain=''):
-        # type: (str, str) -> None
+    def __init__(self, base: str, loginDomain: str = '') -> None:
         """
         :param str base: The base distinguished name.
         :param str loginDomain: The login domain name.
@@ -224,8 +148,7 @@ class position:
         self.__pos = ""
         self.__indomain = False
 
-    def setBase(self, base):
-        # type: (str) -> None
+    def setBase(self, base: str) -> None:
         """
         Set a new base distinguished name.
 
@@ -233,8 +156,7 @@ class position:
         """
         self.__base = base
 
-    def setLoginDomain(self, loginDomain):
-        # type: (str) -> None
+    def setLoginDomain(self, loginDomain: str) -> None:
         """
         Set a new login domain name.
 
@@ -242,13 +164,11 @@ class position:
         """
         self.__loginDomain = loginDomain
 
-    def __setPosition(self, pos):
-        # type: (str) -> None
+    def __setPosition(self, pos: str) -> None:
         self.__pos = pos
         self.__indomain = any(y[0] == 'dc' for x in ldap.dn.str2dn(self.__pos) for y in x)
 
-    def getDn(self):
-        # type: () -> str
+    def getDn(self) -> str:
         """
         Return the distinguished name.
 
@@ -256,8 +176,7 @@ class position:
         """
         return ldap.dn.dn2str(ldap.dn.str2dn(self.__pos) + ldap.dn.str2dn(self.__base))
 
-    def setDn(self, dn):
-        # type: (str) -> None
+    def setDn(self, dn: str) -> None:
         """
         Set a new distinguished name.
 
@@ -270,8 +189,7 @@ class position:
             dn = dn[:-len(base)]
         self.__setPosition(ldap.dn.dn2str(dn))
 
-    def getRdn(self):
-        # type: () -> str
+    def getRdn(self) -> str:
         """
         Return the distinguished name relative to the LDAP base.
 
@@ -279,8 +197,7 @@ class position:
         """
         return ldap.dn.explode_rdn(self.getDn())[0]
 
-    def getBase(self):
-        # type: () -> str
+    def getBase(self) -> str:
         """
         Return the LDAP base DN.
 
@@ -288,8 +205,7 @@ class position:
         """
         return self.__base
 
-    def isBase(self):
-        # type: () -> bool
+    def isBase(self) -> bool:
         """
         Check if the position equals the LDAP base DN.
 
@@ -297,8 +213,7 @@ class position:
         """
         return access.compare_dn(self.getDn(), self.getBase())
 
-    def getDomain(self):
-        # type: () -> str
+    def getDomain(self) -> str:
         """
         Return the distinguished name of the domain part of the position.
 
@@ -313,8 +228,7 @@ class position:
             dn.append(part)
         return ldap.dn.dn2str(dn[::-1])
 
-    def getDomainConfigBase(self):
-        # type: () -> str
+    def getDomainConfigBase(self) -> str:
         """
         Return the distinguished name of the configuration container.
 
@@ -322,8 +236,7 @@ class position:
         """
         return 'cn=univention,' + self.getDomain()
 
-    def isDomain(self):
-        # type: () -> bool
+    def isDomain(self) -> bool:
         """
         Check if the position equals the domain DN.
 
@@ -331,8 +244,7 @@ class position:
         """
         return self.getDn() == self.getDomain()
 
-    def getLoginDomain(self):
-        # type: () -> str
+    def getLoginDomain(self) -> str:
         """
         Return the login domain name.
 
@@ -340,8 +252,7 @@ class position:
         """
         return self.__loginDomain
 
-    def switchToParent(self):
-        # type: () -> bool
+    def switchToParent(self) -> bool:
         """
         Switch position to parent container.
 
@@ -357,8 +268,7 @@ class access:
     """A |UDM| class to access a |LDAP| server."""
 
     @property
-    def binddn(self):
-        # type: () -> str | None
+    def binddn(self) -> str | None:
         """
         Return the distinguished name of the account.
 
@@ -367,8 +277,7 @@ class access:
         return self.lo.binddn
 
     @property
-    def bindpw(self):
-        # type: () -> str
+    def bindpw(self) -> str:
         """
         Return the user password or credentials.
 
@@ -377,8 +286,7 @@ class access:
         return self.lo.bindpw
 
     @property
-    def host(self):
-        # type: () -> str
+    def host(self) -> str:
         """
         Return the host name of the LDAP server.
 
@@ -387,8 +295,7 @@ class access:
         return self.lo.host
 
     @property
-    def port(self):
-        # type: () -> int
+    def port(self) -> int:
         """
         Return the TCP port number of the LDAP server.
 
@@ -397,8 +304,7 @@ class access:
         return self.lo.port
 
     @property
-    def base(self):
-        # type: () -> str
+    def base(self) -> str:
         """
         Return the LDAP base of the LDAP server.
 
@@ -407,22 +313,21 @@ class access:
         return self.lo.base
 
     @property
-    def start_tls(self):
-        # type: () -> int
+    def start_tls(self) -> int:
         return self.lo.start_tls
 
     def __init__(
         self,
-        host='localhost',  # type: str
-        port=None,  # type: int | None
-        base='',  # type: str
-        binddn='',  # type: str
-        bindpw='',  # type: str
-        start_tls=None,  # type: int | None
-        lo=None,  # type: univention.uldap.access | None
-        follow_referral=False,  # type: bool
-        uri=None,  # type: str | None
-    ):  # type: (...) -> None
+        host: str = 'localhost',
+        port: int | None = None,
+        base: str = '',
+        binddn: str = '',
+        bindpw: str = '',
+        start_tls: int | None = None,
+        lo: univention.uldap.access | None = None,
+        follow_referral: bool = False,
+        uri: str | None = None,
+    ) -> None:
         """
         :param host: The hostname of the |LDAP| server.
         :param port: The |TCP| port number of the |LDAP| server.
@@ -449,8 +354,19 @@ class access:
         self.allow_modify = True
         self.licensetypes = ['UCS']
 
-    def bind(self, binddn, bindpw):
-        # type: (str, str) -> None
+        from univention.admin.authorization import Authorization
+        self.authz = Authorization()
+
+    @property
+    def authz_connection(self):
+        """
+        A LDAP connection running with cn=admin priviledges (in case authorization engine is enabled, otherwise just self)
+
+        .. warning :: use carefully: only in combination with manual access control checks to prevent information leak or priviledge escalation
+        """
+        return self.authz.get_authz_connection(self)
+
+    def bind(self, binddn: str, bindpw: str) -> None:
         """
         Do simple LDAP bind using DN and password.
 
@@ -465,8 +381,7 @@ class access:
             raise univention.admin.uexceptions.authFail(_("Authentication failed"))
         self.__require_licence()
 
-    def bind_saml(self, bindpw):
-        # type: (str) -> None
+    def bind_saml(self, bindpw: str) -> None:
         """
         Do LDAP bind using SAML message.
 
@@ -478,8 +393,7 @@ class access:
             raise univention.admin.uexceptions.authFail(_("Authentication failed"))
         self.__require_licence()
 
-    def bind_oauthbearer(self, authzid, bindpw):
-        # type: (str | None, str) -> None
+    def bind_oauthbearer(self, authzid: str | None, bindpw: str) -> None:
         """
         Do LDAP bind using OAuth 2.0 Access Token.
 
@@ -493,8 +407,7 @@ class access:
             raise univention.admin.uexceptions.authFail(_("Authentication failed"))
         self.__require_licence()
 
-    def __require_licence(self):
-        # type: () -> None
+    def __require_licence(self) -> None:
         if self.require_license:
             res = univention.admin.license.init_select(self.lo, 'admin')
 
@@ -536,13 +449,11 @@ class access:
                 self.allow_modify = False
                 raise univention.admin.uexceptions.licenseDVSClients()
 
-    def unbind(self):
-        # type: () -> None
+    def unbind(self) -> None:
         """Unauthenticate."""
         self.lo.unbind()
 
-    def whoami(self):
-        # type: () -> str
+    def whoami(self) -> str:
         """
         Return the distinguished name of the authenticated user.
 
@@ -550,8 +461,7 @@ class access:
         """
         return self.lo.whoami()
 
-    def requireLicense(self, require=True):
-        # type: (bool) -> None
+    def requireLicense(self, require: bool = True) -> None:
         """
         Enable or disable the UCS licence check.
 
@@ -559,14 +469,12 @@ class access:
         """
         self.require_license = require
 
-    def _validateLicense(self):
-        # type: () -> None
+    def _validateLicense(self) -> None:
         """Check if the UCS licence is valid."""
         if self.require_license:
             univention.admin.license.select('admin')
 
-    def get_schema(self):
-        # type: () -> ldap.schema.subentry.SubSchema
+    def get_schema(self) -> ldap.schema.subentry.SubSchema:
         """
         Retrieve |LDAP| schema information from |LDAP| server.
 
@@ -575,8 +483,7 @@ class access:
         return self.lo.get_schema()
 
     @classmethod
-    def compare_dn(cls, a, b):
-        # type: (str, str) -> bool
+    def compare_dn(cls, a: str, b: str) -> bool:
         """
         Compare two distinguished names for equality.
 
@@ -586,8 +493,7 @@ class access:
         """
         return univention.uldap.access.compare_dn(a, b)
 
-    def get(self, dn, attr=[], required=False, exceptions=False):
-        # type: (str, list[str], bool, bool) -> dict[str, list[bytes]]
+    def get(self, dn: str, attr: list[str] = [], required: bool = False, exceptions: bool = False) -> dict[str, list[bytes]]:
         """
         Return multiple attributes of a single LDAP object.
 
@@ -600,8 +506,7 @@ class access:
         """
         return self.lo.get(dn, attr, required)
 
-    def getAttr(self, dn, attr, required=False, exceptions=False):
-        # type: (str, str, bool, bool) -> list[bytes]
+    def getAttr(self, dn: str, attr: str, required: bool = False, exceptions: bool = False) -> list[bytes]:
         """
         Return a single attribute of a single LDAP object.
 
@@ -614,8 +519,7 @@ class access:
         """
         return self.lo.getAttr(dn, attr, required)
 
-    def search(self, filter='(objectClass=*)', base='', scope='sub', attr=[], unique=False, required=False, timeout=-1, sizelimit=0, serverctrls=None, response=None):
-        # type: (str, str, str, list[str], bool, bool, int, int, list[ldap.controls.LDAPControl] | None, dict[str, ldap.controls.LDAPControl] | None) -> list[tuple[str, dict[str, list[bytes]]]]
+    def search(self, filter: str = '(objectClass=*)', base: str = '', scope: str = 'sub', attr: list[str] = [], unique: bool = False, required: bool = False, timeout: int = -1, sizelimit: int = 0, serverctrls: list[ldap.controls.LDAPControl] | None = None, response: dict[str, ldap.controls.LDAPControl] | None = None) -> list[tuple[str, dict[str, list[bytes]]]]:
         """
         Perform LDAP search and return values.
 
@@ -655,8 +559,7 @@ class access:
         except ldap.LDAPError as msg:
             raise univention.admin.uexceptions.ldapError(_err2str(msg), original_exception=msg)
 
-    def searchDn(self, filter='(objectClass=*)', base='', scope='sub', unique=False, required=False, timeout=-1, sizelimit=0, serverctrls=None, response=None):
-        # type: (str, str, str, bool, bool, int, int, list[ldap.controls.LDAPControl] | None, dict[str, ldap.controls.LDAPControl] | None) -> list[str]
+    def searchDn(self, filter: str = '(objectClass=*)', base: str = '', scope: str = 'sub', unique: bool = False, required: bool = False, timeout: int = -1, sizelimit: int = 0, serverctrls: list[ldap.controls.LDAPControl] | None = None, response: dict[str, ldap.controls.LDAPControl] | None = None) -> list[str]:
         """
         Perform LDAP search and return distinguished names only.
 
@@ -695,8 +598,7 @@ class access:
         except ldap.LDAPError as msg:
             raise univention.admin.uexceptions.ldapError(_err2str(msg), original_exception=msg)
 
-    def getPolicies(self, dn, policies=None, attrs=None, result=None, fixedattrs=None):
-        # type: (str, list[str] | None, dict[str, list[Any]] | None, Any, Any) -> dict[str, dict[str, Any]]
+    def getPolicies(self, dn: str, policies: list[str] | None = None, attrs: dict[str, list[Any]] | None = None, result: Any = None, fixedattrs: Any = None) -> dict[str, dict[str, Any]]:
         """
         Return |UCS| policies for |LDAP| entry.
 
@@ -710,8 +612,7 @@ class access:
         udm_log.debug('getPolicies modules dn %s result', dn)
         return self.lo.getPolicies(dn, policies, attrs, result, fixedattrs)
 
-    def add(self, dn, al, exceptions=False, serverctrls=None, response=None, ignore_license=False):
-        # type: (str, list[tuple[str, Any]], bool, list[ldap.controls.LDAPControl] | None, dict | None, bool) -> None
+    def add(self, dn: str, al: list[tuple[str, Any]], exceptions: bool = False, serverctrls: list[ldap.controls.LDAPControl] | None = None, response: dict | None = None, ignore_license: bool = False) -> None:
         """
         Add LDAP entry at distinguished name and attributes in add_list=(attribute-name, old-values. new-values) or (attribute-name, new-values).
 
@@ -748,8 +649,7 @@ class access:
             log.debug('add dn=%s err=%s', dn, msg)
             raise univention.admin.uexceptions.ldapError(_err2str(msg), original_exception=msg)
 
-    def modify(self, dn, changes, exceptions=False, ignore_license=False, serverctrls=None, response=None, rename_callback=None):
-        # type: (str, list[tuple[str, Any, Any]], bool, int, list[ldap.controls.LDAPControl] | None, dict | None, Callable | None) -> str
+    def modify(self, dn: str, changes: list[tuple[str, Any, Any]], exceptions: bool = False, ignore_license: int = False, serverctrls: list[ldap.controls.LDAPControl] | None = None, response: dict | None = None, rename_callback: Callable | None = None) -> str:
         """
         Modify LDAP entry DN with attributes in changes=(attribute-name, old-values, new-values).
 
@@ -782,8 +682,7 @@ class access:
             log.debug('mod dn=%s err=%s', dn, msg)
             raise univention.admin.uexceptions.ldapError(_err2str(msg), original_exception=msg)
 
-    def rename(self, dn, newdn, move_childs=0, ignore_license=False, serverctrls=None, response=None):
-        # type: (str, str, int, bool, list[ldap.controls.LDAPControl] | None, dict | None) -> None
+    def rename(self, dn: str, newdn: str, move_childs: int = 0, ignore_license: bool = False, serverctrls: list[ldap.controls.LDAPControl] | None = None, response: dict | None = None) -> None:
         """
         Rename a LDAP object.
 
@@ -815,8 +714,7 @@ class access:
             log.debug('ren dn=%s err=%s', dn, msg)
             raise univention.admin.uexceptions.ldapError(_err2str(msg), original_exception=msg)
 
-    def delete(self, dn, exceptions=False):
-        # type: (str, bool) -> None
+    def delete(self, dn: str, exceptions: bool = False) -> None:
         """
         Delete a LDAP object.
 
@@ -840,7 +738,7 @@ class access:
             log.debug('del dn=%s err=%s', dn, msg)
             raise univention.admin.uexceptions.noObject(dn)
         except ldap.INSUFFICIENT_ACCESS as msg:
-            log.debug('del dn=%s err=%s', dn, msg)
+            log.debug('del dn=%s err=%s binddn=%s', dn, msg, self.binddn)
             raise univention.admin.uexceptions.permissionDenied()
         except ldap.INVALID_DN_SYNTAX as msg:
             raise univention.admin.uexceptions.ldapError('%s: %s' % (_err2str(msg), dn), original_exception=msg)
@@ -848,8 +746,7 @@ class access:
             log.debug('del dn=%s err=%s', dn, msg)
             raise univention.admin.uexceptions.ldapError(_err2str(msg), original_exception=msg)
 
-    def parentDn(self, dn):
-        # type: (str) -> str | None
+    def parentDn(self, dn: str) -> str | None:
         """
         Return the parent container of a distinguished name.
 
@@ -858,8 +755,7 @@ class access:
         """
         return self.lo.parentDn(dn)
 
-    def explodeDn(self, dn, notypes=False):
-        # type: (str, bool) -> list[str]
+    def explodeDn(self, dn: str, notypes: bool = False) -> list[str]:
         """
         Break up a DN into its component parts.
 
@@ -868,3 +764,39 @@ class access:
         :return: A list of relative distinguished names.
         """
         return self.lo.explodeDn(dn, notypes)
+
+    def filter_lookup_results(self, results, context=None):
+        """Evaluate access control rules for filtering of results"""
+        # TODO: check if we are allowed at all to search in the base, with the scope and the given filter for the attrs
+        return self.authz.filter_search_results(self, results)
+
+    def search_filtered(self, context, filter='(objectClass=*)', base='', *args, **kwargs):
+        if not self._verify_search_base(base) or not self._verify_search_filter(filter):
+            return []
+        results = self.authz_connection.search(filter, base, *args, **kwargs)
+        return self._filter_ldap_search_results(results, dict(kwargs, **(context or {})))
+
+    def search_dn_filtered(self, context, filter='(objectClass=*)', base='', *args, **kwargs):
+        if not self._verify_search_base(base) or not self._verify_search_filter(filter):
+            return []
+        results = self.authz_connection.searchDn(filter, base, *args, **kwargs)
+        return self._filter_ldap_search_dns(results, dict(kwargs, **(context or {})))
+
+    def _filter_ldap_search_results(self, results, options=None):
+        """Evaluate access control rules for filtering of results"""
+        return self.authz.filter_search_results_attrs(self, results)
+
+    def _filter_ldap_search_dns(self, results, context=None):
+        """Evaluate access control rules for filtering of results"""
+        return self.authz.filter_search_results_dn(self, results)
+
+    def _verify_search_base(self, base):
+        # mimic ldapsearch behavior
+        base = base or configRegistry['ldap/base']
+        if not self._filter_ldap_search_dns([base]):
+            raise univention.admin.uexceptions.noObject(base)
+        return True
+
+    def _verify_search_filter(self, filter_s):
+        # TODO: parse search filter and disallow certain filters for UDM property names where no "search" or "read" permission exists
+        return True
